import React, { useState, useCallback, useMemo, useContext, createContext, Fragment, useEffect } from 'react';
import { useTable, useFilters, useGlobalFilter, useGroupBy, useSortBy, useExpanded, usePagination, useRowSelect, useResizeColumns, useFlexLayout, useAsyncDebounce } from 'react-table';
import { Menu, MenuItem, TextField, InputAdornment, Tooltip, IconButton, Chip, FormControlLabel, Switch, Box, Button, Divider, ListItemIcon, TableCell, TableSortLabel, Collapse, Skeleton, Checkbox, TableRow, TableHead, TableBody, TableFooter, Table, TablePagination, useMediaQuery, Alert, LinearProgress, Toolbar, alpha, TableContainer, Paper } from '@mui/material';
import { matchSorter } from 'match-sorter';
import ArrowRightIcon from '@mui/icons-material/ArrowRight';
import CancelIcon from '@mui/icons-material/Cancel';
import CheckBoxIcon from '@mui/icons-material/CheckBox';
import ClearAllIcon from '@mui/icons-material/ClearAll';
import CloseIcon from '@mui/icons-material/Close';
import ContentCopyIcon from '@mui/icons-material/ContentCopy';
import DensityMediumIcon from '@mui/icons-material/DensityMedium';
import DensitySmallIcon from '@mui/icons-material/DensitySmall';
import DoubleArrowDownIcon from '@mui/icons-material/KeyboardDoubleArrowDown';
import DynamicFeedIcon from '@mui/icons-material/DynamicFeed';
import EditIcon from '@mui/icons-material/Edit';
import ExpandLessIcon from '@mui/icons-material/ExpandLess';
import ExpandMoreIcon from '@mui/icons-material/ExpandMore';
import FilterAltIcon from '@mui/icons-material/FilterAlt';
import FilterAltOff from '@mui/icons-material/FilterAltOff';
import FilterListIcon from '@mui/icons-material/FilterList';
import FilterListOffIcon from '@mui/icons-material/FilterListOff';
import FullscreenExitIcon from '@mui/icons-material/FullscreenExit';
import FullscreenIcon from '@mui/icons-material/Fullscreen';
import MoreHorizIcon from '@mui/icons-material/MoreHoriz';
import MoreVertIcon from '@mui/icons-material/MoreVert';
import SaveIcon from '@mui/icons-material/Save';
import SearchIcon from '@mui/icons-material/Search';
import SearchOffIcon from '@mui/icons-material/SearchOff';
import SortIcon from '@mui/icons-material/Sort';
import ViewColumnIcon from '@mui/icons-material/ViewColumn';
import VisibilityOffIcon from '@mui/icons-material/VisibilityOff';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var findLowestLevelCols = function findLowestLevelCols(columns) {
  var lowestLevelColumns = columns;
  var currentCols = columns;

  while (!!((_currentCols = currentCols) != null && _currentCols.length) && currentCols.some(function (col) {
    return col.columns;
  })) {
    var _currentCols;

    var nextCols = currentCols.filter(function (col) {
      return !!col.columns;
    }).map(function (col) {
      return col.columns;
    }).flat();

    if (nextCols.every(function (col) {
      return !(col != null && col.columns);
    })) {
      lowestLevelColumns = [].concat(lowestLevelColumns, nextCols);
    }

    currentCols = nextCols;
  }

  return lowestLevelColumns.filter(function (col) {
    return !col.columns;
  });
};

var MaterialReactTableContext = /*#__PURE__*/function () {
  return createContext({});
}();

var MaterialReactTableProvider = function MaterialReactTableProvider(props) {
  var _props$initialState$d, _props$initialState, _props$initialState$f, _props$initialState2, _props$initialState$s, _props$initialState3, _props$initialState$s2, _props$initialState4;

  var hooks = [useFilters, useGlobalFilter, useGroupBy, useSortBy, useExpanded, usePagination, useRowSelect];
  if (props.enableColumnResizing) hooks.unshift(useResizeColumns, useFlexLayout);

  var _useState = useState(null),
      currentEditingRow = _useState[0],
      setCurrentEditingRow = _useState[1];

  var _useState2 = useState((_props$initialState$d = (_props$initialState = props.initialState) == null ? void 0 : _props$initialState.densePadding) != null ? _props$initialState$d : false),
      densePadding = _useState2[0],
      setDensePadding = _useState2[1];

  var _useState3 = useState((_props$initialState$f = (_props$initialState2 = props.initialState) == null ? void 0 : _props$initialState2.fullScreen) != null ? _props$initialState$f : false),
      fullScreen = _useState3[0],
      setFullScreen = _useState3[1];

  var _useState4 = useState((_props$initialState$s = (_props$initialState3 = props.initialState) == null ? void 0 : _props$initialState3.showFilters) != null ? _props$initialState$s : false),
      showFilters = _useState4[0],
      setShowFilters = _useState4[1];

  var _useState5 = useState((_props$initialState$s2 = (_props$initialState4 = props.initialState) == null ? void 0 : _props$initialState4.showSearch) != null ? _props$initialState$s2 : false),
      showSearch = _useState5[0],
      setShowSearch = _useState5[1];

  var _useState6 = useState(function () {
    return Object.assign.apply(Object, [{}].concat(findLowestLevelCols(props.columns).map(function (c) {
      var _ref, _c$filter, _props$initialState5, _props$initialState5$, _ref2;

      return _ref2 = {}, _ref2[c.accessor] = (_ref = (_c$filter = c.filter) != null ? _c$filter : props == null ? void 0 : (_props$initialState5 = props.initialState) == null ? void 0 : (_props$initialState5$ = _props$initialState5.filters) == null ? void 0 : _props$initialState5$[c.accessor]) != null ? _ref : !!c.filterSelectOptions ? 'equals' : 'fuzzy', _ref2;
    })));
  }),
      currentFilterTypes = _useState6[0],
      setCurrentFilterTypes = _useState6[1];

  var applyFiltersToColumns = useCallback(function (cols) {
    return cols.map(function (column) {
      if (column.columns) {
        applyFiltersToColumns(column.columns);
      } else {
        var _props$filterTypes;

        column.filter = props == null ? void 0 : (_props$filterTypes = props.filterTypes) == null ? void 0 : _props$filterTypes[currentFilterTypes[column.accessor]];
      }

      return column;
    });
  }, [currentFilterTypes, props.filterTypes]);
  var columns = useMemo(function () {
    return applyFiltersToColumns(props.columns);
  }, [props.columns, applyFiltersToColumns]);
  var data = useMemo(function () {
    return !props.isLoading || !!props.data.length ? props.data : [].concat(Array(10).fill(null)).map(function (_) {
      return Object.assign.apply(Object, [{}].concat(findLowestLevelCols(props.columns).map(function (c) {
        var _ref3;

        return _ref3 = {}, _ref3[c.accessor] = null, _ref3;
      })));
    });
  }, [props.data, props.isLoading]);
  var tableInstance = useTable.apply(void 0, [// @ts-ignore
  _extends({}, props, {
    // @ts-ignore
    columns: columns,
    data: data,
    useControlledState: function useControlledState(state) {
      return useMemo(function () {
        return _extends({}, state, {
          currentEditingRow: currentEditingRow,
          currentFilterTypes: currentFilterTypes,
          densePadding: densePadding,
          fullScreen: fullScreen,
          showFilters: showFilters,
          showSearch: showSearch
        }, props == null ? void 0 : props.useControlledState == null ? void 0 : props.useControlledState(state));
      }, [currentEditingRow, currentFilterTypes, densePadding, fullScreen, showFilters, showSearch, state]);
    }
  })].concat(hooks));
  var idPrefix = useMemo(function () {
    var _props$idPrefix;

    return (_props$idPrefix = props.idPrefix) != null ? _props$idPrefix : Math.random().toString(36).substring(2, 9);
  }, [props.idPrefix]);
  var anyRowsCanExpand = useMemo(function () {
    return tableInstance.rows.some(function (row) {
      return row.canExpand;
    });
  }, [tableInstance.rows]);
  var anyRowsExpanded = useMemo(function () {
    return tableInstance.rows.some(function (row) {
      return row.isExpanded;
    });
  }, [tableInstance.rows]);
  return React.createElement(MaterialReactTableContext.Provider, {
    value: _extends({}, props, {
      anyRowsCanExpand: anyRowsCanExpand,
      anyRowsExpanded: anyRowsExpanded,
      idPrefix: idPrefix,
      //@ts-ignore
      setCurrentEditingRow: setCurrentEditingRow,
      setCurrentFilterTypes: setCurrentFilterTypes,
      setDensePadding: setDensePadding,
      setFullScreen: setFullScreen,
      setShowFilters: setShowFilters,
      setShowSearch: setShowSearch,
      //@ts-ignore
      tableInstance: tableInstance
    })
  }, props.children);
};
var useMRT = function useMRT() {
  return useContext(MaterialReactTableContext);
};

var MRT_FILTER_TYPE;

(function (MRT_FILTER_TYPE) {
  MRT_FILTER_TYPE["CONTAINS"] = "contains";
  MRT_FILTER_TYPE["EMPTY"] = "empty";
  MRT_FILTER_TYPE["ENDS_WITH"] = "endsWith";
  MRT_FILTER_TYPE["EQUALS"] = "equals";
  MRT_FILTER_TYPE["FUZZY"] = "fuzzy";
  MRT_FILTER_TYPE["GREATER_THAN"] = "greaterThan";
  MRT_FILTER_TYPE["LESS_THAN"] = "lessThan";
  MRT_FILTER_TYPE["NOT_EMPTY"] = "notEmpty";
  MRT_FILTER_TYPE["NOT_EQUALS"] = "notEquals";
  MRT_FILTER_TYPE["STARTS_WITH"] = "startsWith";
})(MRT_FILTER_TYPE || (MRT_FILTER_TYPE = {}));

var fuzzy = function fuzzy(rows, columnIds, filterValue) {
  return matchSorter(rows, filterValue.toString().trim(), {
    keys: Array.isArray(columnIds) ? columnIds.map(function (c) {
      return "values." + c;
    }) : ["values." + columnIds],
    sorter: function sorter(rankedItems) {
      return rankedItems;
    }
  });
};

fuzzy.autoRemove = function (val) {
  return !val;
};

var contains = function contains(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim().includes(filterValue.toString().toLowerCase().trim());
  });
};

contains.autoRemove = function (val) {
  return !val;
};

var startsWith = function startsWith(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim().startsWith(filterValue.toString().toLowerCase().trim());
  });
};

startsWith.autoRemove = function (val) {
  return !val;
};

var endsWith = function endsWith(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim().endsWith(filterValue.toString().toLowerCase().trim());
  });
};

endsWith.autoRemove = function (val) {
  return !val;
};

var equals = function equals(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim() === filterValue.toString().toLowerCase().trim();
  });
};

equals.autoRemove = function (val) {
  return !val;
};

var notEquals = function notEquals(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim() !== filterValue.toString().toLowerCase().trim();
  });
};

notEquals.autoRemove = function (val) {
  return !val;
};

var greaterThan = function greaterThan(rows, id, filterValue) {
  return rows.filter(function (row) {
    return !isNaN(+filterValue) && !isNaN(+row.values[id]) ? +row.values[id] > +filterValue : row.values[id].toString().toLowerCase().trim() > filterValue.toString().toLowerCase().trim();
  });
};

greaterThan.autoRemove = function (val) {
  return !val;
};

var lessThan = function lessThan(rows, id, filterValue) {
  return rows.filter(function (row) {
    return !isNaN(+filterValue) && !isNaN(+row.values[id]) ? +row.values[id] < +filterValue : row.values[id].toString().toLowerCase().trim() < filterValue.toString().toLowerCase().trim();
  });
};

lessThan.autoRemove = function (val) {
  return !val;
};

var empty = function empty(rows, id, _filterValue) {
  return rows.filter(function (row) {
    return !row.values[id].toString().toLowerCase().trim();
  });
};

empty.autoRemove = function (val) {
  return !val;
};

var notEmpty = function notEmpty(rows, id, _filterValue) {
  return rows.filter(function (row) {
    return !!row.values[id].toString().toLowerCase().trim();
  });
};

notEmpty.autoRemove = function (val) {
  return !val;
};

var defaultFilterFNs = {
  contains: contains,
  empty: empty,
  endsWith: endsWith,
  equals: equals,
  fuzzy: fuzzy,
  greaterThan: greaterThan,
  lessThan: lessThan,
  notEmpty: notEmpty,
  notEquals: notEquals,
  startsWith: startsWith
};

var commonMenuItemStyles = {
  py: '6px',
  my: 0,
  alignItems: 'center'
};
var MRT_FilterTypeMenu = function MRT_FilterTypeMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      column = _ref.column,
      onSelect = _ref.onSelect,
      setAnchorEl = _ref.setAnchorEl;

  var _useMRT = useMRT(),
      localization = _useMRT.localization,
      setCurrentFilterTypes = _useMRT.setCurrentFilterTypes,
      tableInstance = _useMRT.tableInstance;

  var filterTypes = useMemo(function () {
    return [{
      type: MRT_FILTER_TYPE.FUZZY,
      label: localization.filterFuzzy,
      divider: false,
      fn: fuzzy
    }, {
      type: MRT_FILTER_TYPE.CONTAINS,
      label: localization.filterContains,
      divider: true,
      fn: contains
    }, {
      type: MRT_FILTER_TYPE.STARTS_WITH,
      label: localization.filterStartsWith,
      divider: false,
      fn: startsWith
    }, {
      type: MRT_FILTER_TYPE.ENDS_WITH,
      label: localization.filterEndsWith,
      divider: true,
      fn: endsWith
    }, {
      type: MRT_FILTER_TYPE.EQUALS,
      label: localization.filterEquals,
      divider: false,
      fn: equals
    }, {
      type: MRT_FILTER_TYPE.NOT_EQUALS,
      label: localization.filterNotEquals,
      divider: true,
      fn: notEquals
    }, {
      type: MRT_FILTER_TYPE.GREATER_THAN,
      label: localization.filterGreaterThan,
      divider: false,
      fn: greaterThan
    }, {
      type: MRT_FILTER_TYPE.LESS_THAN,
      label: localization.filterLessThan,
      divider: true,
      fn: lessThan
    }, {
      type: MRT_FILTER_TYPE.EMPTY,
      label: localization.filterEmpty,
      divider: false,
      fn: empty
    }, {
      type: MRT_FILTER_TYPE.NOT_EMPTY,
      label: localization.filterNotEmpty,
      divider: false,
      fn: notEmpty
    }].filter(function (filterType) {
      return !column.filterTypes || column.filterTypes.includes(filterType.type);
    });
  }, []);

  var handleSelectFilterType = function handleSelectFilterType(value) {
    setAnchorEl(null);
    setCurrentFilterTypes(function (prev) {
      var _extends2;

      return _extends({}, prev, (_extends2 = {}, _extends2[column.id] = value, _extends2));
    });

    if ([MRT_FILTER_TYPE.EMPTY, MRT_FILTER_TYPE.NOT_EMPTY].includes(value)) {
      column.setFilter(' ');
    }

    onSelect == null ? void 0 : onSelect();
  };

  var filterType = tableInstance.state.currentFilterTypes[column.id];
  return React.createElement(Menu, {
    anchorEl: anchorEl,
    anchorOrigin: {
      vertical: 'center',
      horizontal: 'right'
    },
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    open: !!anchorEl,
    MenuListProps: {
      dense: tableInstance.state.densePadding
    }
  }, filterTypes.map(function (_ref2, index) {
    var type = _ref2.type,
        label = _ref2.label,
        divider = _ref2.divider,
        fn = _ref2.fn;
    return React.createElement(MenuItem, {
      divider: divider,
      key: index,
      onClick: function onClick() {
        return handleSelectFilterType(type);
      },
      selected: type === filterType || fn === filterType,
      sx: commonMenuItemStyles,
      value: type
    }, label);
  }));
};

var MRT_FilterTextField = function MRT_FilterTextField(_ref) {
  var _localization$filterB, _localization$filterM, _localization$, _localization$clearFi, _column$filterSelectO;

  var column = _ref.column;

  var _useMRT = useMRT(),
      _useMRT$icons = _useMRT.icons,
      FilterListIcon = _useMRT$icons.FilterListIcon,
      CloseIcon = _useMRT$icons.CloseIcon,
      idPrefix = _useMRT.idPrefix,
      localization = _useMRT.localization,
      muiTableHeadCellFilterTextFieldProps = _useMRT.muiTableHeadCellFilterTextFieldProps,
      setCurrentFilterTypes = _useMRT.setCurrentFilterTypes,
      tableInstance = _useMRT.tableInstance;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var mTableHeadCellFilterTextFieldProps = muiTableHeadCellFilterTextFieldProps instanceof Function ? muiTableHeadCellFilterTextFieldProps(column) : muiTableHeadCellFilterTextFieldProps;
  var mcTableHeadCellFilterTextFieldProps = column.muiTableHeadCellFilterTextFieldProps instanceof Function ? column.muiTableHeadCellFilterTextFieldProps(column) : column.muiTableHeadCellFilterTextFieldProps;

  var textFieldProps = _extends({}, mTableHeadCellFilterTextFieldProps, mcTableHeadCellFilterTextFieldProps);

  var _useState2 = useState(''),
      filterValue = _useState2[0],
      setFilterValue = _useState2[1];

  var handleChange = useAsyncDebounce(function (value) {
    column.setFilter(value != null ? value : undefined);
  }, 150);

  var handleFilterMenuOpen = function handleFilterMenuOpen(event) {
    setAnchorEl(event.currentTarget);
  };

  var handleClear = function handleClear() {
    setFilterValue('');
    column.setFilter(undefined);
  };

  var handleClearFilterChip = function handleClearFilterChip() {
    setFilterValue('');
    column.setFilter(undefined);
    setCurrentFilterTypes(function (prev) {
      var _extends2;

      return _extends({}, prev, (_extends2 = {}, _extends2[column.id] = MRT_FILTER_TYPE.FUZZY, _extends2));
    });
  };

  if (column.Filter) {
    return React.createElement(React.Fragment, null, column.Filter == null ? void 0 : column.Filter({
      column: column
    }));
  }

  var filterId = "mrt-" + idPrefix + "-" + column.id + "-filter-text-field";
  var filterType = tableInstance.state.currentFilterTypes[column.id];
  var isSelectFilter = !!column.filterSelectOptions;
  var filterChipLabel = !(filterType instanceof Function) && [MRT_FILTER_TYPE.EMPTY, MRT_FILTER_TYPE.NOT_EMPTY].includes(filterType) ? //@ts-ignore
  localization["filter" + (filterType.charAt(0).toUpperCase() + filterType.slice(1))] : '';
  var filterPlaceholder = (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(column.Header));
  return React.createElement(React.Fragment, null, React.createElement(TextField, Object.assign({
    fullWidth: true,
    id: filterId,
    inputProps: {
      disabled: !!filterChipLabel,
      sx: {
        textOverflow: 'ellipsis',
        width: filterChipLabel ? 0 : undefined
      },
      title: filterPlaceholder
    },
    helperText: React.createElement("label", {
      htmlFor: filterId
    }, filterType instanceof Function ? (_localization$filterM = localization.filterMode.replace('{filterType}', // @ts-ignore
    (_localization$ = localization["filter" + (filterType.name.charAt(0).toUpperCase() + filterType.name.slice(1))]) != null ? _localization$ : '')) != null ? _localization$filterM : '' : localization.filterMode.replace('{filterType}', // @ts-ignore
    localization["filter" + (filterType.charAt(0).toUpperCase() + filterType.slice(1))])),
    FormHelperTextProps: {
      sx: {
        fontSize: '0.6rem',
        lineHeight: '0.8rem'
      }
    },
    label: isSelectFilter && !filterValue ? filterPlaceholder : undefined,
    InputLabelProps: {
      shrink: false,
      sx: {
        maxWidth: 'calc(100% - 2.5rem)'
      },
      title: filterPlaceholder
    },
    margin: "none",
    placeholder: filterChipLabel || isSelectFilter ? undefined : filterPlaceholder,
    onChange: function onChange(e) {
      setFilterValue(e.target.value);
      handleChange(e.target.value);
    },
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    select: isSelectFilter,
    value: filterValue != null ? filterValue : '',
    variant: "standard",
    InputProps: {
      startAdornment: !isSelectFilter && React.createElement(InputAdornment, {
        position: "start"
      }, React.createElement(Tooltip, {
        arrow: true,
        title: localization.changeFilterMode
      }, React.createElement("span", null, React.createElement(IconButton, {
        "aria-label": localization.changeFilterMode,
        onClick: handleFilterMenuOpen,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React.createElement(FilterListIcon, null)))), filterChipLabel && React.createElement(Chip, {
        onDelete: handleClearFilterChip,
        label: filterChipLabel
      })),
      endAdornment: !filterChipLabel && React.createElement(InputAdornment, {
        position: "end"
      }, React.createElement(Tooltip, {
        arrow: true,
        disableHoverListener: isSelectFilter,
        placement: "right",
        title: (_localization$clearFi = localization.clearFilter) != null ? _localization$clearFi : ''
      }, React.createElement("span", null, React.createElement(IconButton, {
        "aria-label": localization.clearFilter,
        disabled: !(filterValue != null && filterValue.length),
        onClick: handleClear,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React.createElement(CloseIcon, {
        fontSize: "small"
      })))))
    }
  }, textFieldProps, {
    sx: _extends({
      m: '-0.25rem',
      p: 0,
      minWidth: !filterChipLabel ? '5rem' : 'auto',
      width: 'calc(100% + 0.5rem)',
      mt: isSelectFilter && !filterValue ? '-1rem' : undefined,
      '&	.MuiSelect-icon': {
        mr: '1.5rem'
      }
    }, textFieldProps == null ? void 0 : textFieldProps.sx)
  }), isSelectFilter && React.createElement(MenuItem, {
    divider: true,
    disabled: !filterValue,
    value: ""
  }, localization.clearFilter), column == null ? void 0 : (_column$filterSelectO = column.filterSelectOptions) == null ? void 0 : _column$filterSelectO.map(function (option) {
    var value;
    var text;

    if (typeof option === 'string') {
      value = option;
      text = option;
    } else if (typeof option === 'object') {
      value = option.value;
      text = option.text;
    }

    return React.createElement(MenuItem, {
      key: value,
      value: value
    }, text);
  })), React.createElement(MRT_FilterTypeMenu, {
    anchorEl: anchorEl,
    column: column,
    setAnchorEl: setAnchorEl
  }));
};

var MRT_ShowHideColumnsMenuItems = function MRT_ShowHideColumnsMenuItems(_ref) {
  var _column$columns, _column$columns2, _column$isVisible, _column$columns4;

  var column = _ref.column,
      isSubMenu = _ref.isSubMenu;

  var _useMRT = useMRT(),
      onColumnHide = _useMRT.onColumnHide,
      tableInstance = _useMRT.tableInstance;

  var isParentHeader = !!(column != null && (_column$columns = column.columns) != null && _column$columns.length);
  var allChildColumnsVisible = isParentHeader && !!((_column$columns2 = column.columns) != null && _column$columns2.every(function (childColumn) {
    return childColumn.isVisible;
  }));
  var switchChecked = (_column$isVisible = column.isVisible) != null ? _column$isVisible : allChildColumnsVisible;

  var handleToggleColumnHidden = function handleToggleColumnHidden(column) {
    if (isParentHeader) {
      var _column$columns3;

      column == null ? void 0 : (_column$columns3 = column.columns) == null ? void 0 : _column$columns3.forEach == null ? void 0 : _column$columns3.forEach(function (childColumn) {
        childColumn.toggleHidden(switchChecked);
      });
    } else {
      column.toggleHidden();
    }

    onColumnHide == null ? void 0 : onColumnHide(column, tableInstance.state.hiddenColumns);
  };

  return React.createElement(React.Fragment, null, React.createElement(MenuItem, {
    sx: _extends({}, commonMenuItemStyles$1, {
      pl: (column.depth + 0.5) * 2 + "rem"
    })
  }, React.createElement(FormControlLabel, {
    componentsProps: {
      typography: {
        sx: {
          marginBottom: 0
        }
      }
    },
    checked: switchChecked,
    control: React.createElement(Switch, null),
    disabled: isSubMenu && switchChecked || column.disableColumnHiding,
    label: column.Header,
    onChange: function onChange() {
      return handleToggleColumnHidden(column);
    }
  })), (_column$columns4 = column.columns) == null ? void 0 : _column$columns4.map(function (c, i) {
    return React.createElement(MRT_ShowHideColumnsMenuItems, {
      key: i + "-" + c.id,
      column: c,
      isSubMenu: isSubMenu
    });
  }));
};

var MRT_ShowHideColumnsMenu = function MRT_ShowHideColumnsMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      isSubMenu = _ref.isSubMenu,
      setAnchorEl = _ref.setAnchorEl;

  var _useMRT = useMRT(),
      localization = _useMRT.localization,
      tableInstance = _useMRT.tableInstance;

  var hideAllColumns = function hideAllColumns() {
    findLowestLevelCols(tableInstance.columns).filter(function (col) {
      return !col.disableColumnHiding;
    }).forEach(function (col) {
      return col.toggleHidden(true);
    });
  };

  return React.createElement(Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: tableInstance.state.densePadding
    }
  }, React.createElement(Box, {
    sx: {
      display: 'flex',
      justifyContent: isSubMenu ? 'center' : 'space-between',
      p: '0.5rem',
      pt: 0
    }
  }, !isSubMenu && React.createElement(Button, {
    disabled: !tableInstance.getToggleHideAllColumnsProps().checked && !tableInstance.getToggleHideAllColumnsProps().indeterminate,
    onClick: hideAllColumns
  }, localization.hideAll), React.createElement(Button, {
    disabled: tableInstance.getToggleHideAllColumnsProps().checked,
    onClick: function onClick() {
      return tableInstance.toggleHideAllColumns(false);
    }
  }, localization.showAll)), React.createElement(Divider, null), tableInstance.columns.map(function (column, index) {
    return React.createElement(MRT_ShowHideColumnsMenuItems, {
      column: column,
      isSubMenu: isSubMenu,
      key: index + "-" + column.id
    });
  }));
};

var commonMenuItemStyles$1 = {
  py: '6px',
  my: 0,
  justifyContent: 'space-between',
  alignItems: 'center'
};
var commonListItemStyles = {
  display: 'flex',
  alignItems: 'center'
};
var MRT_ColumnActionMenu = function MRT_ColumnActionMenu(_ref) {
  var _localization$sortByC, _localization$sortByC2, _localization$filterB, _localization, _localization$hideCol, _tableInstance$state$, _localization$showAll;

  var anchorEl = _ref.anchorEl,
      column = _ref.column,
      setAnchorEl = _ref.setAnchorEl;

  var _useMRT = useMRT(),
      disableColumnHiding = _useMRT.disableColumnHiding,
      disableFilters = _useMRT.disableFilters,
      disableSortBy = _useMRT.disableSortBy,
      enableColumnGrouping = _useMRT.enableColumnGrouping,
      _useMRT$icons = _useMRT.icons,
      ArrowRightIcon = _useMRT$icons.ArrowRightIcon,
      ClearAllIcon = _useMRT$icons.ClearAllIcon,
      ViewColumnIcon = _useMRT$icons.ViewColumnIcon,
      DynamicFeedIcon = _useMRT$icons.DynamicFeedIcon,
      FilterListIcon = _useMRT$icons.FilterListIcon,
      FilterListOffIcon = _useMRT$icons.FilterListOffIcon,
      SortIcon = _useMRT$icons.SortIcon,
      VisibilityOffIcon = _useMRT$icons.VisibilityOffIcon,
      idPrefix = _useMRT.idPrefix,
      localization = _useMRT.localization,
      setShowFilters = _useMRT.setShowFilters,
      tableInstance = _useMRT.tableInstance;

  var _useState = useState(null),
      filterMenuAnchorEl = _useState[0],
      setFilterMenuAnchorEl = _useState[1];

  var _useState2 = useState(null),
      showHideColumnsMenuAnchorEl = _useState2[0],
      setShowHideColumnsMenuAnchorEl = _useState2[1];

  var handleClearSort = function handleClearSort() {
    column.clearSortBy();
    setAnchorEl(null);
  };

  var handleSortAsc = function handleSortAsc() {
    column.toggleSortBy(false);
    setAnchorEl(null);
  };

  var handleSortDesc = function handleSortDesc() {
    column.toggleSortBy(true);
    setAnchorEl(null);
  };

  var handleHideColumn = function handleHideColumn() {
    column.toggleHidden();
    setAnchorEl(null);
  };

  var handleGroupByColumn = function handleGroupByColumn() {
    column.toggleGroupBy();
    setAnchorEl(null);
  };

  var handleClearFilter = function handleClearFilter() {
    column.setFilter('');
    setAnchorEl(null);
  };

  var handleFilterByColumn = function handleFilterByColumn() {
    setShowFilters(true);
    setTimeout(function () {
      var _document$getElementB, _column$muiTableHeadC, _column$muiTableHeadC2;

      return (_document$getElementB = document.getElementById( // @ts-ignore
      (_column$muiTableHeadC = (_column$muiTableHeadC2 = column.muiTableHeadCellFilterTextFieldProps) == null ? void 0 : _column$muiTableHeadC2.id) != null ? _column$muiTableHeadC : "mrt-" + idPrefix + "-" + column.id + "-filter-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
    setAnchorEl(null);
  };

  var handleShowAllColumns = function handleShowAllColumns() {
    tableInstance.toggleHideAllColumns(false);
    setAnchorEl(null);
  };

  var handleOpenFilterModeMenu = function handleOpenFilterModeMenu(event) {
    event.stopPropagation();
    setFilterMenuAnchorEl(event.currentTarget);
  };

  var handleOpenShowHideColumnsMenu = function handleOpenShowHideColumnsMenu(event) {
    event.stopPropagation();
    setShowHideColumnsMenuAnchorEl(event.currentTarget);
  };

  return React.createElement(Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: tableInstance.state.densePadding
    }
  }, !disableSortBy && column.canSort && [React.createElement(MenuItem, {
    disabled: !column.isSorted,
    key: 0,
    onClick: handleClearSort,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(ClearAllIcon, null)), localization.clearSort)), React.createElement(MenuItem, {
    disabled: column.isSorted && !column.isSortedDesc,
    key: 1,
    onClick: handleSortAsc,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(SortIcon, null)), (_localization$sortByC = localization.sortByColumnAsc) == null ? void 0 : _localization$sortByC.replace('{column}', String(column.Header)))), React.createElement(MenuItem, {
    divider: !disableFilters || enableColumnGrouping || !disableColumnHiding,
    key: 2,
    disabled: column.isSorted && column.isSortedDesc,
    onClick: handleSortDesc,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(SortIcon, {
    style: {
      transform: 'rotate(180deg) scaleX(-1)'
    }
  })), (_localization$sortByC2 = localization.sortByColumnDesc) == null ? void 0 : _localization$sortByC2.replace('{column}', String(column.Header))))], !disableFilters && column.canFilter && [React.createElement(MenuItem, {
    disabled: !column.filterValue,
    key: 0,
    onClick: handleClearFilter,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(FilterListOffIcon, null)), localization.clearFilter)), React.createElement(MenuItem, {
    divider: enableColumnGrouping || !disableColumnHiding,
    key: 1,
    onClick: handleFilterByColumn,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(FilterListIcon, null)), (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(column.Header))), !column.filterSelectOptions && React.createElement(IconButton, {
    onClick: handleOpenFilterModeMenu,
    onMouseEnter: handleOpenFilterModeMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React.createElement(ArrowRightIcon, null))), React.createElement(MRT_FilterTypeMenu, {
    anchorEl: filterMenuAnchorEl,
    column: column,
    key: 2,
    setAnchorEl: setFilterMenuAnchorEl,
    onSelect: handleFilterByColumn
  })], enableColumnGrouping && column.canGroupBy && [React.createElement(MenuItem, {
    divider: !disableColumnHiding,
    key: 0,
    onClick: handleGroupByColumn,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(DynamicFeedIcon, null)), (_localization = localization[column.isGrouped ? 'ungroupByColumn' : 'groupByColumn']) == null ? void 0 : _localization.replace('{column}', String(column.Header))))], !disableColumnHiding && [React.createElement(MenuItem, {
    disabled: column.disableColumnHiding,
    key: 0,
    onClick: handleHideColumn,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(VisibilityOffIcon, null)), (_localization$hideCol = localization.hideColumn) == null ? void 0 : _localization$hideCol.replace('{column}', String(column.Header)))), React.createElement(MenuItem, {
    disabled: !((_tableInstance$state$ = tableInstance.state.hiddenColumns) != null && _tableInstance$state$.length),
    key: 1,
    onClick: handleShowAllColumns,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(ViewColumnIcon, null)), (_localization$showAll = localization.showAllColumns) == null ? void 0 : _localization$showAll.replace('{column}', String(column.Header))), !column.filterSelectOptions && React.createElement(IconButton, {
    onClick: handleOpenShowHideColumnsMenu,
    onMouseEnter: handleOpenShowHideColumnsMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React.createElement(ArrowRightIcon, null))), React.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: showHideColumnsMenuAnchorEl,
    isSubMenu: true,
    key: 2,
    setAnchorEl: setShowHideColumnsMenuAnchorEl
  })]);
};

var MRT_ToggleColumnActionMenuButton = function MRT_ToggleColumnActionMenuButton(_ref) {
  var column = _ref.column;

  var _useMRT = useMRT(),
      MoreVertIcon = _useMRT.icons.MoreVertIcon,
      localization = _useMRT.localization,
      muiTableHeadCellColumnActionsButtonProps = _useMRT.muiTableHeadCellColumnActionsButtonProps;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var mTableHeadCellColumnActionsButtonProps = muiTableHeadCellColumnActionsButtonProps instanceof Function ? muiTableHeadCellColumnActionsButtonProps(column) : muiTableHeadCellColumnActionsButtonProps;
  var mcTableHeadCellColumnActionsButtonProps = column.muiTableHeadCellColumnActionsButtonProps instanceof Function ? column.muiTableHeadCellColumnActionsButtonProps(column) : column.muiTableHeadCellColumnActionsButtonProps;

  var iconButtonProps = _extends({}, mTableHeadCellColumnActionsButtonProps, mcTableHeadCellColumnActionsButtonProps);

  return React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: localization.columnActions
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.columnActions,
    onClick: handleClick,
    size: "small"
  }, iconButtonProps, {
    sx: _extends({
      height: '2rem',
      mr: '2px',
      mt: '-0.2rem',
      opacity: 0.5,
      transition: 'opacity 0.2s',
      width: '2rem',
      '&:hover': {
        opacity: 1
      }
    }, iconButtonProps.sx)
  }), React.createElement(MoreVertIcon, null))), React.createElement(MRT_ColumnActionMenu, {
    anchorEl: anchorEl,
    column: column,
    setAnchorEl: setAnchorEl
  }));
};

var commonTableHeadCellStyles = function commonTableHeadCellStyles(densePadding, enableColumnResizing, widths) {
  return _extends({
    fontWeight: 'bold',
    height: '100%',
    p: densePadding ? '0.5rem' : '1rem',
    pt: densePadding ? '0.75rem' : '1.25rem',
    transition: "all " + (enableColumnResizing ? '10ms' : '0.2s') + " ease-in-out",
    verticalAlign: 'text-top'
  }, widths);
};
var MRT_TableHeadCell = function MRT_TableHeadCell(_ref) {
  var _column$columns, _localization$sortByC, _localization$sortByC2;

  var column = _ref.column;

  var _useMRT = useMRT(),
      disableColumnActions = _useMRT.disableColumnActions,
      disableFilters = _useMRT.disableFilters,
      enableColumnResizing = _useMRT.enableColumnResizing,
      _useMRT$icons = _useMRT.icons,
      FilterAltIcon = _useMRT$icons.FilterAltIcon,
      FilterAltOff = _useMRT$icons.FilterAltOff,
      localization = _useMRT.localization,
      muiTableHeadCellProps = _useMRT.muiTableHeadCellProps,
      setShowFilters = _useMRT.setShowFilters,
      tableInstance = _useMRT.tableInstance;

  var isParentHeader = !!(column != null && (_column$columns = column.columns) != null && _column$columns.length);
  var mTableHeadCellProps = muiTableHeadCellProps instanceof Function ? muiTableHeadCellProps(column) : muiTableHeadCellProps;
  var mcTableHeadCellProps = column.muiTableHeadCellProps instanceof Function ? column.muiTableHeadCellProps(column) : column.muiTableHeadCellProps;

  var tableCellProps = _extends({}, mTableHeadCellProps, mcTableHeadCellProps, column.getHeaderProps(), {
    style: _extends({}, column.getHeaderProps().style, mTableHeadCellProps == null ? void 0 : mTableHeadCellProps.style, mcTableHeadCellProps == null ? void 0 : mcTableHeadCellProps.style)
  });

  var sortTooltip = column.isSorted ? column.isSortedDesc ? localization.clearSort : (_localization$sortByC = localization.sortByColumnDesc) == null ? void 0 : _localization$sortByC.replace('{column}', column.Header) : (_localization$sortByC2 = localization.sortByColumnAsc) == null ? void 0 : _localization$sortByC2.replace('{column}', column.Header);
  var filterType = tableInstance.state.currentFilterTypes[column.id];
  var filterTooltip = !!column.filterValue ? localization.filteringByColumn.replace('{column}', String(column.Header)).replace('{filterType}', filterType instanceof Function ? '' : // @ts-ignore
  localization["filter" + (filterType.charAt(0).toUpperCase() + filterType.slice(1))]).replace('{filterValue}', column.filterValue) : localization.showHideFilters;
  var columnHeader = column.render('Header');
  return React.createElement(TableCell, Object.assign({
    align: isParentHeader ? 'center' : 'left'
  }, tableCellProps, {
    sx: _extends({}, commonTableHeadCellStyles(tableInstance.state.densePadding, enableColumnResizing, {
      maxWidth: column.maxWidth,
      minWidth: column.minWidth,
      width: column.width
    }), tableCellProps == null ? void 0 : tableCellProps.sx)
  }), React.createElement(Box, {
    sx: {
      alignItems: 'flex-start',
      display: 'flex',
      justifyContent: isParentHeader ? 'center' : 'space-between',
      width: '100%'
    }
  }, React.createElement(Box, Object.assign({}, column.getSortByToggleProps(), {
    sx: {
      alignItems: 'center',
      display: 'flex',
      flexWrap: 'nowrap',
      whiteSpace: columnHeader.length < 15 ? 'nowrap' : 'normal'
    },
    title: undefined
  }), column.render('Header'), !isParentHeader && column.canSort && React.createElement(Tooltip, {
    arrow: true,
    placement: "top",
    title: sortTooltip
  }, React.createElement(TableSortLabel, {
    "aria-label": sortTooltip,
    active: column.isSorted,
    direction: column.isSortedDesc ? 'desc' : 'asc'
  })), !isParentHeader && !!column.canFilter && React.createElement(Tooltip, {
    arrow: true,
    placement: "top",
    title: filterTooltip
  }, React.createElement(IconButton, {
    disableRipple: true,
    onClick: function onClick(event) {
      event.stopPropagation();
      setShowFilters(!tableInstance.state.showFilters);
    },
    size: "small",
    sx: {
      m: 0,
      opacity: !!column.filterValue ? 0.8 : 0,
      p: '2px',
      transition: 'all 0.2s ease-in-out',
      '&:hover': {
        backgroundColor: 'transparent',
        opacity: 0.8
      }
    }
  }, tableInstance.state.showFilters && !column.filterValue ? React.createElement(FilterAltOff, {
    fontSize: "small"
  }) : React.createElement(FilterAltIcon, {
    fontSize: "small"
  })))), React.createElement(Box, {
    sx: {
      alignItems: 'center',
      display: 'flex',
      flexWrap: 'nowrap'
    }
  }, !disableColumnActions && !column.disableColumnActions && !isParentHeader && React.createElement(MRT_ToggleColumnActionMenuButton, {
    column: column
  }), enableColumnResizing && !isParentHeader && React.createElement(Divider, Object.assign({
    flexItem: true,
    orientation: "vertical",
    onDoubleClick: function onDoubleClick() {
      return tableInstance.resetResizing();
    }
  }, column.getResizerProps(), {
    sx: {
      borderRightWidth: '2px',
      borderRadius: '2px',
      maxHeight: '2rem'
    }
  })))), !disableFilters && column.canFilter && React.createElement(Collapse, {
    "in": tableInstance.state.showFilters
  }, React.createElement(MRT_FilterTextField, {
    column: column
  })));
};

var MRT_EditCellTextField = function MRT_EditCellTextField(_ref) {
  var cell = _ref.cell;

  var _useMRT = useMRT(),
      muiTableBodyCellEditTextFieldProps = _useMRT.muiTableBodyCellEditTextFieldProps,
      setCurrentEditingRow = _useMRT.setCurrentEditingRow,
      currentEditingRow = _useMRT.tableInstance.state.currentEditingRow;

  var handleChange = function handleChange(event) {
    if (currentEditingRow) {
      cell.row.values[cell.column.id] = event.target.value;
      setCurrentEditingRow(_extends({}, currentEditingRow));
    }

    cell.column.onCellEditChange == null ? void 0 : cell.column.onCellEditChange(event, cell);
  };

  var mTableBodyCellEditTextFieldProps = muiTableBodyCellEditTextFieldProps instanceof Function ? muiTableBodyCellEditTextFieldProps(cell) : muiTableBodyCellEditTextFieldProps;
  var mcTableBodyCellEditTextFieldProps = cell.column.muiTableBodyCellEditTextFieldProps instanceof Function ? cell.column.muiTableBodyCellEditTextFieldProps(cell) : cell.column.muiTableBodyCellEditTextFieldProps;

  var textFieldProps = _extends({}, mTableBodyCellEditTextFieldProps, mcTableBodyCellEditTextFieldProps);

  if (!cell.column.disableEditing && cell.column.Edit) {
    return React.createElement(React.Fragment, null, cell.column.Edit(_extends({}, textFieldProps, {
      cell: cell
    })));
  }

  return React.createElement(TextField, Object.assign({
    margin: "dense",
    onChange: handleChange,
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    placeholder: cell.column.Header,
    value: cell.value,
    variant: "standard"
  }, textFieldProps));
};

var MRT_CopyButton = function MRT_CopyButton(_ref) {
  var cell = _ref.cell;

  var _useMRT = useMRT(),
      localization = _useMRT.localization;

  var _useState = useState(false),
      copied = _useState[0],
      setCopied = _useState[1];

  var handleCopy = function handleCopy(text) {
    navigator.clipboard.writeText(text);
    setCopied(true);
    setTimeout(function () {
      return setCopied(false);
    }, 4000);
  };

  return React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: copied ? localization.copiedToClipboard : localization.clickToCopy
  }, React.createElement(Button, {
    "aria-label": localization.clickToCopy,
    onClick: function onClick() {
      return handleCopy(cell.value);
    },
    size: "small",
    sx: {
      backgroundColor: 'transparent',
      color: 'inherit',
      letterSpacing: 'inherit',
      fontFamily: 'inherit',
      fontSize: 'inherit',
      m: '-0.25rem',
      textTransform: 'inherit',
      textAlign: 'inherit',
      minWidth: 'unset'
    },
    variant: "text"
  }, cell.render('Cell')));
};

var commonTableBodyCellStyles = function commonTableBodyCellStyles(densePadding) {
  return {
    p: densePadding ? '0.5rem' : '1rem',
    transition: 'all 0.2s ease-in-out',
    whiteSpace: densePadding ? 'nowrap' : 'normal'
  };
};
var commonTableBodyButtonCellStyles = function commonTableBodyButtonCellStyles(densePadding) {
  return {
    p: densePadding ? '1px' : '0.6rem',
    textAlign: 'center',
    transition: 'all 0.2s ease-in-out'
  };
};
var MRT_TableBodyCell = function MRT_TableBodyCell(_ref) {
  var cell = _ref.cell;

  var _useMRT = useMRT(),
      enableClickToCopy = _useMRT.enableClickToCopy,
      isLoading = _useMRT.isLoading,
      muiTableBodyCellProps = _useMRT.muiTableBodyCellProps,
      muiTableBodyCellSkeletonProps = _useMRT.muiTableBodyCellSkeletonProps,
      onCellClick = _useMRT.onCellClick,
      _useMRT$tableInstance = _useMRT.tableInstance.state,
      currentEditingRow = _useMRT$tableInstance.currentEditingRow,
      densePadding = _useMRT$tableInstance.densePadding;

  var mTableCellBodyProps = muiTableBodyCellProps instanceof Function ? muiTableBodyCellProps(cell) : muiTableBodyCellProps;
  var mcTableCellBodyProps = cell.column.muiTableBodyCellProps instanceof Function ? cell.column.muiTableBodyCellProps(cell) : cell.column.muiTableBodyCellProps;

  var tableCellProps = _extends({}, mTableCellBodyProps, mcTableCellBodyProps, cell.getCellProps(), {
    style: _extends({}, cell.getCellProps().style, mTableCellBodyProps == null ? void 0 : mTableCellBodyProps.style, mcTableCellBodyProps == null ? void 0 : mcTableCellBodyProps.style)
  });

  return React.createElement(TableCell, Object.assign({
    onClick: function onClick(event) {
      return onCellClick == null ? void 0 : onCellClick(event, cell);
    }
  }, tableCellProps, {
    sx: _extends({}, commonTableBodyCellStyles(densePadding), tableCellProps == null ? void 0 : tableCellProps.sx)
  }), isLoading ? React.createElement(Skeleton, Object.assign({
    animation: "wave",
    height: 20,
    width: Math.random() * (120 - 60) + 60
  }, muiTableBodyCellSkeletonProps)) : !cell.column.disableEditing && (currentEditingRow == null ? void 0 : currentEditingRow.id) === cell.row.id ? React.createElement(MRT_EditCellTextField, {
    cell: cell
  }) : cell.isPlaceholder ? null : cell.isAggregated ? cell.render('Aggregated') : cell.isGrouped ? React.createElement("span", null, cell.render('Cell'), " (", cell.row.subRows.length, ")") : enableClickToCopy && !cell.column.disableClickToCopy ? React.createElement(MRT_CopyButton, {
    cell: cell
  }) : cell.render('Cell'));
};

var MRT_SelectCheckbox = function MRT_SelectCheckbox(_ref) {
  var row = _ref.row,
      selectAll = _ref.selectAll;

  var _useMRT = useMRT(),
      localization = _useMRT.localization,
      muiSelectCheckboxProps = _useMRT.muiSelectCheckboxProps,
      onSelectChange = _useMRT.onSelectChange,
      onSelectAllChange = _useMRT.onSelectAllChange,
      tableInstance = _useMRT.tableInstance,
      densePadding = _useMRT.tableInstance.state.densePadding;

  var handleSelectChange = function handleSelectChange(event) {
    if (selectAll) {
      var _tableInstance$getTog;

      tableInstance == null ? void 0 : tableInstance.getToggleAllRowsSelectedProps == null ? void 0 : (_tableInstance$getTog = tableInstance.getToggleAllRowsSelectedProps()) == null ? void 0 : _tableInstance$getTog.onChange == null ? void 0 : _tableInstance$getTog.onChange(event);
      onSelectAllChange == null ? void 0 : onSelectAllChange(event, event.target.checked ? tableInstance.rows : []);
    } else if (row) {
      var _row$getToggleRowSele;

      row == null ? void 0 : (_row$getToggleRowSele = row.getToggleRowSelectedProps()) == null ? void 0 : _row$getToggleRowSele.onChange == null ? void 0 : _row$getToggleRowSele.onChange(event);
      onSelectChange == null ? void 0 : onSelectChange(event, row, event.target.checked ? [].concat(tableInstance.selectedFlatRows, [row]) : tableInstance.selectedFlatRows.filter(function (selectedRow) {
        return selectedRow.id !== row.id;
      }));
    }
  };

  var mTableBodyRowSelectCheckboxProps = muiSelectCheckboxProps instanceof Function ? muiSelectCheckboxProps(selectAll, row, tableInstance) : muiSelectCheckboxProps;
  var rtSelectCheckboxProps = selectAll ? tableInstance.getToggleAllRowsSelectedProps() : row == null ? void 0 : row.getToggleRowSelectedProps();

  var checkboxProps = _extends({}, mTableBodyRowSelectCheckboxProps, rtSelectCheckboxProps, {
    style: _extends({}, rtSelectCheckboxProps == null ? void 0 : rtSelectCheckboxProps.style, mTableBodyRowSelectCheckboxProps == null ? void 0 : mTableBodyRowSelectCheckboxProps.style)
  });

  return React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
  }, React.createElement(Checkbox, Object.assign({
    inputProps: {
      'aria-label': selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
    },
    size: densePadding ? 'small' : 'medium'
  }, checkboxProps, {
    onChange: handleSelectChange,
    title: undefined
  })));
};

var MRT_ExpandAllButton = function MRT_ExpandAllButton() {
  var _useMRT = useMRT(),
      anyRowsExpanded = _useMRT.anyRowsExpanded,
      DoubleArrowDownIcon = _useMRT.icons.DoubleArrowDownIcon,
      localization = _useMRT.localization,
      tableInstance = _useMRT.tableInstance;

  return React.createElement(TableCell, Object.assign({
    size: "small"
  }, tableInstance.getToggleAllRowsExpandedProps(), {
    sx: commonTableBodyButtonCellStyles(tableInstance.state.densePadding)
  }), React.createElement(IconButton, {
    "aria-label": localization.expandAll,
    title: localization.expandAll
  }, React.createElement(DoubleArrowDownIcon, {
    style: {
      transform: "rotate(" + (tableInstance.isAllRowsExpanded ? -180 : anyRowsExpanded ? -90 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  })));
};

var MRT_TableSpacerCell = function MRT_TableSpacerCell(_ref) {
  var width = _ref.width;

  var _useMRT = useMRT(),
      muiTableBodyCellProps = _useMRT.muiTableBodyCellProps;

  var tableCellProps = muiTableBodyCellProps instanceof Function ? muiTableBodyCellProps() : muiTableBodyCellProps;
  return React.createElement(TableCell, Object.assign({}, tableCellProps, {
    sx: _extends({
      width: width
    }, tableCellProps == null ? void 0 : tableCellProps.sx)
  }));
};

var MRT_TableHeadCellActions = function MRT_TableHeadCellActions() {
  var _useMRT = useMRT(),
      localization = _useMRT.localization,
      densePadding = _useMRT.tableInstance.state.densePadding;

  return React.createElement(TableCell, {
    style: {
      textAlign: 'center'
    },
    sx: _extends({}, commonTableHeadCellStyles(densePadding), {
      textAlign: 'center',
      maxWidth: '4rem',
      width: '4rem'
    })
  }, localization.actions);
};

var MRT_TableHeadRow = function MRT_TableHeadRow(_ref) {
  var headerGroup = _ref.headerGroup;

  var _useMRT = useMRT(),
      anyRowsCanExpand = _useMRT.anyRowsCanExpand,
      disableExpandAll = _useMRT.disableExpandAll,
      disableSelectAll = _useMRT.disableSelectAll,
      enableRowActions = _useMRT.enableRowActions,
      enableRowEditing = _useMRT.enableRowEditing,
      enableRowNumbers = _useMRT.enableRowNumbers,
      enableSelection = _useMRT.enableSelection,
      muiTableHeadRowProps = _useMRT.muiTableHeadRowProps,
      positionActionsColumn = _useMRT.positionActionsColumn,
      renderDetailPanel = _useMRT.renderDetailPanel,
      tableInstance = _useMRT.tableInstance;

  var isParentHeader = useMemo(function () {
    return headerGroup.headers.some(function (h) {
      var _h$columns$length, _h$columns;

      return ((_h$columns$length = (_h$columns = h.columns) == null ? void 0 : _h$columns.length) != null ? _h$columns$length : 0) > 0;
    });
  }, [headerGroup.headers]);
  var mTableHeadRowProps = muiTableHeadRowProps instanceof Function ? muiTableHeadRowProps(headerGroup) : muiTableHeadRowProps;

  var tableRowProps = _extends({}, mTableHeadRowProps, headerGroup.getHeaderGroupProps(), {
    style: _extends({}, headerGroup.getHeaderGroupProps().style, mTableHeadRowProps == null ? void 0 : mTableHeadRowProps.style)
  });

  return React.createElement(TableRow, Object.assign({}, tableRowProps), enableRowNumbers && (isParentHeader ? React.createElement(MRT_TableSpacerCell, null) : React.createElement(TableCell, {
    sx: _extends({}, commonTableHeadCellStyles(tableInstance.state.densePadding))
  }, "#")), (enableRowActions || enableRowEditing) && positionActionsColumn === 'first' && (isParentHeader ? React.createElement(MRT_TableSpacerCell, null) : React.createElement(MRT_TableHeadCellActions, null)), anyRowsCanExpand || renderDetailPanel ? !disableExpandAll && !isParentHeader ? React.createElement(MRT_ExpandAllButton, null) : React.createElement(MRT_TableSpacerCell, {
    width: (renderDetailPanel ? 2 : tableInstance.expandedDepth + 0.5) + "rem"
  }) : null, enableSelection ? !isParentHeader && !disableSelectAll ? React.createElement(TableCell, {
    sx: _extends({}, commonTableBodyButtonCellStyles(tableInstance.state.densePadding), {
      maxWidth: '3rem',
      width: '3rem'
    })
  }, React.createElement(MRT_SelectCheckbox, {
    selectAll: true
  })) : React.createElement(MRT_TableSpacerCell, {
    width: "1rem"
  }) : null, headerGroup.headers.map(function (column) {
    return React.createElement(MRT_TableHeadCell, {
      key: column.getHeaderProps().key,
      column: column
    });
  }), (enableRowActions || enableRowEditing) && positionActionsColumn === 'last' && (isParentHeader ? React.createElement(MRT_TableSpacerCell, null) : React.createElement(MRT_TableHeadCellActions, null)));
};

var MRT_TableHead = function MRT_TableHead() {
  var _useMRT = useMRT(),
      tableInstance = _useMRT.tableInstance,
      muiTableHeadProps = _useMRT.muiTableHeadProps;

  var tableHeadProps = muiTableHeadProps instanceof Function ? muiTableHeadProps(tableInstance) : muiTableHeadProps;
  return React.createElement(TableHead, Object.assign({}, tableHeadProps), tableInstance.headerGroups.map(function (headerGroup) {
    return React.createElement(MRT_TableHeadRow, {
      key: headerGroup.getHeaderGroupProps().key,
      headerGroup: headerGroup
    });
  }));
};

var MRT_TableDetailPanel = function MRT_TableDetailPanel(_ref) {
  var row = _ref.row;

  var _useMRT = useMRT(),
      muiTableBodyRowProps = _useMRT.muiTableBodyRowProps,
      muiTableDetailPanelProps = _useMRT.muiTableDetailPanelProps,
      onDetailPanelClick = _useMRT.onDetailPanelClick,
      renderDetailPanel = _useMRT.renderDetailPanel,
      tableInstance = _useMRT.tableInstance;

  var tableRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps(row) : muiTableBodyRowProps;
  var tableCellProps = muiTableDetailPanelProps instanceof Function ? muiTableDetailPanelProps(row) : muiTableDetailPanelProps;
  return React.createElement(TableRow, Object.assign({}, tableRowProps), React.createElement(TableCell, Object.assign({
    colSpan: tableInstance.visibleColumns.length + 10,
    onClick: function onClick(event) {
      return onDetailPanelClick == null ? void 0 : onDetailPanelClick(event, row);
    }
  }, tableCellProps, {
    sx: _extends({
      borderBottom: !row.isExpanded ? 'none' : undefined,
      pb: row.isExpanded ? '1rem' : 0,
      pt: row.isExpanded ? '1rem' : 0,
      transition: 'all 0.2s ease-in-out'
    }, tableCellProps == null ? void 0 : tableCellProps.sx)
  }), React.createElement(Collapse, {
    "in": row.isExpanded
  }, renderDetailPanel == null ? void 0 : renderDetailPanel(row))));
};

var MRT_ExpandButton = function MRT_ExpandButton(_ref) {
  var row = _ref.row;

  var _useMRT = useMRT(),
      ExpandMoreIcon = _useMRT.icons.ExpandMoreIcon,
      localization = _useMRT.localization,
      onRowExpandChange = _useMRT.onRowExpandChange,
      renderDetailPanel = _useMRT.renderDetailPanel,
      densePadding = _useMRT.tableInstance.state.densePadding;

  var handleToggleExpand = function handleToggleExpand(event) {
    var _row$getToggleRowExpa;

    // @ts-ignore
    (_row$getToggleRowExpa = row.getToggleRowExpandedProps()) == null ? void 0 : _row$getToggleRowExpa.onClick(event);
    onRowExpandChange == null ? void 0 : onRowExpandChange(event, row);
  };

  return React.createElement(TableCell, {
    size: "small",
    sx: _extends({}, commonTableBodyButtonCellStyles(densePadding), {
      pl: row.depth + 0.5 + "rem",
      textAlign: 'left'
    })
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.expand,
    disabled: !row.canExpand && !renderDetailPanel,
    title: localization.expand
  }, row.getToggleRowExpandedProps(), {
    onClick: handleToggleExpand
  }), React.createElement(ExpandMoreIcon, {
    style: {
      transform: "rotate(" + (!row.canExpand && !renderDetailPanel ? -90 : row.isExpanded ? -180 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  })));
};

var MRT_RowActionMenu = function MRT_RowActionMenu(_ref) {
  var _renderRowActionMenuI;

  var anchorEl = _ref.anchorEl,
      row = _ref.row,
      handleEdit = _ref.handleEdit,
      setAnchorEl = _ref.setAnchorEl;

  var _useMRT = useMRT(),
      EditIcon = _useMRT.icons.EditIcon,
      enableRowEditing = _useMRT.enableRowEditing,
      localization = _useMRT.localization,
      renderRowActionMenuItems = _useMRT.renderRowActionMenuItems,
      tableInstance = _useMRT.tableInstance;

  return React.createElement(Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: tableInstance.state.densePadding
    }
  }, enableRowEditing && React.createElement(MenuItem, {
    onClick: handleEdit,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(EditIcon, null)), localization.edit)), (_renderRowActionMenuI = renderRowActionMenuItems == null ? void 0 : renderRowActionMenuItems(row, tableInstance, function () {
    return setAnchorEl(null);
  })) != null ? _renderRowActionMenuI : null);
};

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var runtime_1 = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2014-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var runtime = (function (exports) {

  var Op = Object.prototype;
  var hasOwn = Op.hasOwnProperty;
  var undefined$1; // More compressible than void 0.
  var $Symbol = typeof Symbol === "function" ? Symbol : {};
  var iteratorSymbol = $Symbol.iterator || "@@iterator";
  var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
  var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

  function define(obj, key, value) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
    return obj[key];
  }
  try {
    // IE 8 has a broken Object.defineProperty that only works on DOM objects.
    define({}, "");
  } catch (err) {
    define = function(obj, key, value) {
      return obj[key] = value;
    };
  }

  function wrap(innerFn, outerFn, self, tryLocsList) {
    // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
    var generator = Object.create(protoGenerator.prototype);
    var context = new Context(tryLocsList || []);

    // The ._invoke method unifies the implementations of the .next,
    // .throw, and .return methods.
    generator._invoke = makeInvokeMethod(innerFn, self, context);

    return generator;
  }
  exports.wrap = wrap;

  // Try/catch helper to minimize deoptimizations. Returns a completion
  // record like context.tryEntries[i].completion. This interface could
  // have been (and was previously) designed to take a closure to be
  // invoked without arguments, but in all the cases we care about we
  // already have an existing method we want to call, so there's no need
  // to create a new function object. We can even get away with assuming
  // the method takes exactly one argument, since that happens to be true
  // in every case, so we don't have to touch the arguments object. The
  // only additional allocation required is the completion record, which
  // has a stable shape and so hopefully should be cheap to allocate.
  function tryCatch(fn, obj, arg) {
    try {
      return { type: "normal", arg: fn.call(obj, arg) };
    } catch (err) {
      return { type: "throw", arg: err };
    }
  }

  var GenStateSuspendedStart = "suspendedStart";
  var GenStateSuspendedYield = "suspendedYield";
  var GenStateExecuting = "executing";
  var GenStateCompleted = "completed";

  // Returning this object from the innerFn has the same effect as
  // breaking out of the dispatch switch statement.
  var ContinueSentinel = {};

  // Dummy constructor functions that we use as the .constructor and
  // .constructor.prototype properties for functions that return Generator
  // objects. For full spec compliance, you may wish to configure your
  // minifier not to mangle the names of these two functions.
  function Generator() {}
  function GeneratorFunction() {}
  function GeneratorFunctionPrototype() {}

  // This is a polyfill for %IteratorPrototype% for environments that
  // don't natively support it.
  var IteratorPrototype = {};
  define(IteratorPrototype, iteratorSymbol, function () {
    return this;
  });

  var getProto = Object.getPrototypeOf;
  var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
  if (NativeIteratorPrototype &&
      NativeIteratorPrototype !== Op &&
      hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
    // This environment has a native %IteratorPrototype%; use it instead
    // of the polyfill.
    IteratorPrototype = NativeIteratorPrototype;
  }

  var Gp = GeneratorFunctionPrototype.prototype =
    Generator.prototype = Object.create(IteratorPrototype);
  GeneratorFunction.prototype = GeneratorFunctionPrototype;
  define(Gp, "constructor", GeneratorFunctionPrototype);
  define(GeneratorFunctionPrototype, "constructor", GeneratorFunction);
  GeneratorFunction.displayName = define(
    GeneratorFunctionPrototype,
    toStringTagSymbol,
    "GeneratorFunction"
  );

  // Helper for defining the .next, .throw, and .return methods of the
  // Iterator interface in terms of a single ._invoke method.
  function defineIteratorMethods(prototype) {
    ["next", "throw", "return"].forEach(function(method) {
      define(prototype, method, function(arg) {
        return this._invoke(method, arg);
      });
    });
  }

  exports.isGeneratorFunction = function(genFun) {
    var ctor = typeof genFun === "function" && genFun.constructor;
    return ctor
      ? ctor === GeneratorFunction ||
        // For the native GeneratorFunction constructor, the best we can
        // do is to check its .name property.
        (ctor.displayName || ctor.name) === "GeneratorFunction"
      : false;
  };

  exports.mark = function(genFun) {
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
    } else {
      genFun.__proto__ = GeneratorFunctionPrototype;
      define(genFun, toStringTagSymbol, "GeneratorFunction");
    }
    genFun.prototype = Object.create(Gp);
    return genFun;
  };

  // Within the body of any async function, `await x` is transformed to
  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
  // `hasOwn.call(value, "__await")` to determine if the yielded value is
  // meant to be awaited.
  exports.awrap = function(arg) {
    return { __await: arg };
  };

  function AsyncIterator(generator, PromiseImpl) {
    function invoke(method, arg, resolve, reject) {
      var record = tryCatch(generator[method], generator, arg);
      if (record.type === "throw") {
        reject(record.arg);
      } else {
        var result = record.arg;
        var value = result.value;
        if (value &&
            typeof value === "object" &&
            hasOwn.call(value, "__await")) {
          return PromiseImpl.resolve(value.__await).then(function(value) {
            invoke("next", value, resolve, reject);
          }, function(err) {
            invoke("throw", err, resolve, reject);
          });
        }

        return PromiseImpl.resolve(value).then(function(unwrapped) {
          // When a yielded Promise is resolved, its final value becomes
          // the .value of the Promise<{value,done}> result for the
          // current iteration.
          result.value = unwrapped;
          resolve(result);
        }, function(error) {
          // If a rejected Promise was yielded, throw the rejection back
          // into the async generator function so it can be handled there.
          return invoke("throw", error, resolve, reject);
        });
      }
    }

    var previousPromise;

    function enqueue(method, arg) {
      function callInvokeWithMethodAndArg() {
        return new PromiseImpl(function(resolve, reject) {
          invoke(method, arg, resolve, reject);
        });
      }

      return previousPromise =
        // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(
          callInvokeWithMethodAndArg,
          // Avoid propagating failures to Promises returned by later
          // invocations of the iterator.
          callInvokeWithMethodAndArg
        ) : callInvokeWithMethodAndArg();
    }

    // Define the unified helper method that is used to implement .next,
    // .throw, and .return (see defineIteratorMethods).
    this._invoke = enqueue;
  }

  defineIteratorMethods(AsyncIterator.prototype);
  define(AsyncIterator.prototype, asyncIteratorSymbol, function () {
    return this;
  });
  exports.AsyncIterator = AsyncIterator;

  // Note that simple async functions are implemented on top of
  // AsyncIterator objects; they just return a Promise for the value of
  // the final result produced by the iterator.
  exports.async = function(innerFn, outerFn, self, tryLocsList, PromiseImpl) {
    if (PromiseImpl === void 0) PromiseImpl = Promise;

    var iter = new AsyncIterator(
      wrap(innerFn, outerFn, self, tryLocsList),
      PromiseImpl
    );

    return exports.isGeneratorFunction(outerFn)
      ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function(result) {
          return result.done ? result.value : iter.next();
        });
  };

  function makeInvokeMethod(innerFn, self, context) {
    var state = GenStateSuspendedStart;

    return function invoke(method, arg) {
      if (state === GenStateExecuting) {
        throw new Error("Generator is already running");
      }

      if (state === GenStateCompleted) {
        if (method === "throw") {
          throw arg;
        }

        // Be forgiving, per 25.3.3.3.3 of the spec:
        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
        return doneResult();
      }

      context.method = method;
      context.arg = arg;

      while (true) {
        var delegate = context.delegate;
        if (delegate) {
          var delegateResult = maybeInvokeDelegate(delegate, context);
          if (delegateResult) {
            if (delegateResult === ContinueSentinel) continue;
            return delegateResult;
          }
        }

        if (context.method === "next") {
          // Setting context._sent for legacy support of Babel's
          // function.sent implementation.
          context.sent = context._sent = context.arg;

        } else if (context.method === "throw") {
          if (state === GenStateSuspendedStart) {
            state = GenStateCompleted;
            throw context.arg;
          }

          context.dispatchException(context.arg);

        } else if (context.method === "return") {
          context.abrupt("return", context.arg);
        }

        state = GenStateExecuting;

        var record = tryCatch(innerFn, self, context);
        if (record.type === "normal") {
          // If an exception is thrown from innerFn, we leave state ===
          // GenStateExecuting and loop back for another invocation.
          state = context.done
            ? GenStateCompleted
            : GenStateSuspendedYield;

          if (record.arg === ContinueSentinel) {
            continue;
          }

          return {
            value: record.arg,
            done: context.done
          };

        } else if (record.type === "throw") {
          state = GenStateCompleted;
          // Dispatch the exception by looping back around to the
          // context.dispatchException(context.arg) call above.
          context.method = "throw";
          context.arg = record.arg;
        }
      }
    };
  }

  // Call delegate.iterator[context.method](context.arg) and handle the
  // result, either by returning a { value, done } result from the
  // delegate iterator, or by modifying context.method and context.arg,
  // setting context.delegate to null, and returning the ContinueSentinel.
  function maybeInvokeDelegate(delegate, context) {
    var method = delegate.iterator[context.method];
    if (method === undefined$1) {
      // A .throw or .return when the delegate iterator has no .throw
      // method always terminates the yield* loop.
      context.delegate = null;

      if (context.method === "throw") {
        // Note: ["return"] must be used for ES3 parsing compatibility.
        if (delegate.iterator["return"]) {
          // If the delegate iterator has a return method, give it a
          // chance to clean up.
          context.method = "return";
          context.arg = undefined$1;
          maybeInvokeDelegate(delegate, context);

          if (context.method === "throw") {
            // If maybeInvokeDelegate(context) changed context.method from
            // "return" to "throw", let that override the TypeError below.
            return ContinueSentinel;
          }
        }

        context.method = "throw";
        context.arg = new TypeError(
          "The iterator does not provide a 'throw' method");
      }

      return ContinueSentinel;
    }

    var record = tryCatch(method, delegate.iterator, context.arg);

    if (record.type === "throw") {
      context.method = "throw";
      context.arg = record.arg;
      context.delegate = null;
      return ContinueSentinel;
    }

    var info = record.arg;

    if (! info) {
      context.method = "throw";
      context.arg = new TypeError("iterator result is not an object");
      context.delegate = null;
      return ContinueSentinel;
    }

    if (info.done) {
      // Assign the result of the finished delegate to the temporary
      // variable specified by delegate.resultName (see delegateYield).
      context[delegate.resultName] = info.value;

      // Resume execution at the desired location (see delegateYield).
      context.next = delegate.nextLoc;

      // If context.method was "throw" but the delegate handled the
      // exception, let the outer generator proceed normally. If
      // context.method was "next", forget context.arg since it has been
      // "consumed" by the delegate iterator. If context.method was
      // "return", allow the original .return call to continue in the
      // outer generator.
      if (context.method !== "return") {
        context.method = "next";
        context.arg = undefined$1;
      }

    } else {
      // Re-yield the result returned by the delegate method.
      return info;
    }

    // The delegate iterator is finished, so forget it and continue with
    // the outer generator.
    context.delegate = null;
    return ContinueSentinel;
  }

  // Define Generator.prototype.{next,throw,return} in terms of the
  // unified ._invoke helper method.
  defineIteratorMethods(Gp);

  define(Gp, toStringTagSymbol, "Generator");

  // A Generator should always return itself as the iterator object when the
  // @@iterator function is called on it. Some browsers' implementations of the
  // iterator prototype chain incorrectly implement this, causing the Generator
  // object to not be returned from this call. This ensures that doesn't happen.
  // See https://github.com/facebook/regenerator/issues/274 for more details.
  define(Gp, iteratorSymbol, function() {
    return this;
  });

  define(Gp, "toString", function() {
    return "[object Generator]";
  });

  function pushTryEntry(locs) {
    var entry = { tryLoc: locs[0] };

    if (1 in locs) {
      entry.catchLoc = locs[1];
    }

    if (2 in locs) {
      entry.finallyLoc = locs[2];
      entry.afterLoc = locs[3];
    }

    this.tryEntries.push(entry);
  }

  function resetTryEntry(entry) {
    var record = entry.completion || {};
    record.type = "normal";
    delete record.arg;
    entry.completion = record;
  }

  function Context(tryLocsList) {
    // The root entry object (effectively a try statement without a catch
    // or a finally block) gives us a place to store values thrown from
    // locations where there is no enclosing try statement.
    this.tryEntries = [{ tryLoc: "root" }];
    tryLocsList.forEach(pushTryEntry, this);
    this.reset(true);
  }

  exports.keys = function(object) {
    var keys = [];
    for (var key in object) {
      keys.push(key);
    }
    keys.reverse();

    // Rather than returning an object with a next method, we keep
    // things simple and return the next function itself.
    return function next() {
      while (keys.length) {
        var key = keys.pop();
        if (key in object) {
          next.value = key;
          next.done = false;
          return next;
        }
      }

      // To avoid creating an additional object, we just hang the .value
      // and .done properties off the next function object itself. This
      // also ensures that the minifier will not anonymize the function.
      next.done = true;
      return next;
    };
  };

  function values(iterable) {
    if (iterable) {
      var iteratorMethod = iterable[iteratorSymbol];
      if (iteratorMethod) {
        return iteratorMethod.call(iterable);
      }

      if (typeof iterable.next === "function") {
        return iterable;
      }

      if (!isNaN(iterable.length)) {
        var i = -1, next = function next() {
          while (++i < iterable.length) {
            if (hasOwn.call(iterable, i)) {
              next.value = iterable[i];
              next.done = false;
              return next;
            }
          }

          next.value = undefined$1;
          next.done = true;

          return next;
        };

        return next.next = next;
      }
    }

    // Return an iterator with no values.
    return { next: doneResult };
  }
  exports.values = values;

  function doneResult() {
    return { value: undefined$1, done: true };
  }

  Context.prototype = {
    constructor: Context,

    reset: function(skipTempReset) {
      this.prev = 0;
      this.next = 0;
      // Resetting context._sent for legacy support of Babel's
      // function.sent implementation.
      this.sent = this._sent = undefined$1;
      this.done = false;
      this.delegate = null;

      this.method = "next";
      this.arg = undefined$1;

      this.tryEntries.forEach(resetTryEntry);

      if (!skipTempReset) {
        for (var name in this) {
          // Not sure about the optimal order of these conditions:
          if (name.charAt(0) === "t" &&
              hasOwn.call(this, name) &&
              !isNaN(+name.slice(1))) {
            this[name] = undefined$1;
          }
        }
      }
    },

    stop: function() {
      this.done = true;

      var rootEntry = this.tryEntries[0];
      var rootRecord = rootEntry.completion;
      if (rootRecord.type === "throw") {
        throw rootRecord.arg;
      }

      return this.rval;
    },

    dispatchException: function(exception) {
      if (this.done) {
        throw exception;
      }

      var context = this;
      function handle(loc, caught) {
        record.type = "throw";
        record.arg = exception;
        context.next = loc;

        if (caught) {
          // If the dispatched exception was caught by a catch block,
          // then let that catch block handle the exception normally.
          context.method = "next";
          context.arg = undefined$1;
        }

        return !! caught;
      }

      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        var record = entry.completion;

        if (entry.tryLoc === "root") {
          // Exception thrown outside of any try block that could handle
          // it, so set the completion value of the entire function to
          // throw the exception.
          return handle("end");
        }

        if (entry.tryLoc <= this.prev) {
          var hasCatch = hasOwn.call(entry, "catchLoc");
          var hasFinally = hasOwn.call(entry, "finallyLoc");

          if (hasCatch && hasFinally) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            } else if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else if (hasCatch) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            }

          } else if (hasFinally) {
            if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else {
            throw new Error("try statement without catch or finally");
          }
        }
      }
    },

    abrupt: function(type, arg) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc <= this.prev &&
            hasOwn.call(entry, "finallyLoc") &&
            this.prev < entry.finallyLoc) {
          var finallyEntry = entry;
          break;
        }
      }

      if (finallyEntry &&
          (type === "break" ||
           type === "continue") &&
          finallyEntry.tryLoc <= arg &&
          arg <= finallyEntry.finallyLoc) {
        // Ignore the finally entry if control is not jumping to a
        // location outside the try/catch block.
        finallyEntry = null;
      }

      var record = finallyEntry ? finallyEntry.completion : {};
      record.type = type;
      record.arg = arg;

      if (finallyEntry) {
        this.method = "next";
        this.next = finallyEntry.finallyLoc;
        return ContinueSentinel;
      }

      return this.complete(record);
    },

    complete: function(record, afterLoc) {
      if (record.type === "throw") {
        throw record.arg;
      }

      if (record.type === "break" ||
          record.type === "continue") {
        this.next = record.arg;
      } else if (record.type === "return") {
        this.rval = this.arg = record.arg;
        this.method = "return";
        this.next = "end";
      } else if (record.type === "normal" && afterLoc) {
        this.next = afterLoc;
      }

      return ContinueSentinel;
    },

    finish: function(finallyLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.finallyLoc === finallyLoc) {
          this.complete(entry.completion, entry.afterLoc);
          resetTryEntry(entry);
          return ContinueSentinel;
        }
      }
    },

    "catch": function(tryLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc === tryLoc) {
          var record = entry.completion;
          if (record.type === "throw") {
            var thrown = record.arg;
            resetTryEntry(entry);
          }
          return thrown;
        }
      }

      // The context.catch method must only be called with a location
      // argument that corresponds to a known catch block.
      throw new Error("illegal catch attempt");
    },

    delegateYield: function(iterable, resultName, nextLoc) {
      this.delegate = {
        iterator: values(iterable),
        resultName: resultName,
        nextLoc: nextLoc
      };

      if (this.method === "next") {
        // Deliberately forget the last sent value so that we don't
        // accidentally pass it on to the delegate.
        this.arg = undefined$1;
      }

      return ContinueSentinel;
    }
  };

  // Regardless of whether this script is executing as a CommonJS module
  // or not, return the runtime object so that we can declare the variable
  // regeneratorRuntime in the outer scope, which allows this module to be
  // injected easily by `bin/regenerator --include-runtime script.js`.
  return exports;

}(
  // If this script is executing as a CommonJS module, use module.exports
  // as the regeneratorRuntime namespace. Otherwise create a new empty
  // object. Either way, the resulting object will be used to initialize
  // the regeneratorRuntime variable at the top of this file.
   module.exports 
));

try {
  regeneratorRuntime = runtime;
} catch (accidentalStrictMode) {
  // This module should not be running in strict mode, so the above
  // assignment should always work unless something is misconfigured. Just
  // in case runtime.js accidentally runs in strict mode, in modern engines
  // we can explicitly access globalThis. In older engines we can escape
  // strict mode using a global Function call. This could conceivably fail
  // if a Content Security Policy forbids using Function, but in that case
  // the proper solution is to fix the accidental strict mode problem. If
  // you've misconfigured your bundler to force strict mode and applied a
  // CSP to forbid Function, and you're not willing to fix either of those
  // problems, please detail your unique predicament in a GitHub issue.
  if (typeof globalThis === "object") {
    globalThis.regeneratorRuntime = runtime;
  } else {
    Function("r", "regeneratorRuntime = r")(runtime);
  }
}
});

var MRT_EditActionButtons = function MRT_EditActionButtons(_ref) {
  var row = _ref.row;

  var _useMRT = useMRT(),
      _useMRT$icons = _useMRT.icons,
      CancelIcon = _useMRT$icons.CancelIcon,
      SaveIcon = _useMRT$icons.SaveIcon,
      localization = _useMRT.localization,
      onRowEditSubmit = _useMRT.onRowEditSubmit,
      setCurrentEditingRow = _useMRT.setCurrentEditingRow,
      currentEditingRow = _useMRT.tableInstance.state.currentEditingRow;

  var handleCancel = function handleCancel() {
    row.values = row.original;
    setCurrentEditingRow(null);
  };

  var handleSave = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee() {
      return runtime_1.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return onRowEditSubmit == null ? void 0 : onRowEditSubmit(currentEditingRow != null ? currentEditingRow : row);

            case 2:
              setCurrentEditingRow(null);

            case 3:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function handleSave() {
      return _ref2.apply(this, arguments);
    };
  }();

  return React.createElement(Box, {
    sx: {
      display: 'flex',
      gap: '0.75rem'
    }
  }, React.createElement(Tooltip, {
    arrow: true,
    title: localization.cancel
  }, React.createElement(IconButton, {
    "aria-label": localization.cancel,
    onClick: handleCancel
  }, React.createElement(CancelIcon, null))), React.createElement(Tooltip, {
    arrow: true,
    title: localization.save
  }, React.createElement(IconButton, {
    "aria-label": localization.save,
    color: "info",
    onClick: handleSave
  }, React.createElement(SaveIcon, null))));
};

var commonIconButtonStyles = {
  opacity: 0.5,
  transition: 'opacity 0.2s',
  marginRight: '2px',
  height: '2rem',
  width: '2rem',
  '&:hover': {
    opacity: 1
  }
};
var MRT_ToggleRowActionMenuButton = function MRT_ToggleRowActionMenuButton(_ref) {
  var _tableInstance$state$;

  var row = _ref.row;

  var _useMRT = useMRT(),
      enableRowEditing = _useMRT.enableRowEditing,
      _useMRT$icons = _useMRT.icons,
      EditIcon = _useMRT$icons.EditIcon,
      MoreHorizIcon = _useMRT$icons.MoreHorizIcon,
      localization = _useMRT.localization,
      renderRowActionMenuItems = _useMRT.renderRowActionMenuItems,
      renderRowActions = _useMRT.renderRowActions,
      setCurrentEditingRow = _useMRT.setCurrentEditingRow,
      tableInstance = _useMRT.tableInstance;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleOpenRowActionMenu = function handleOpenRowActionMenu(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var handleEdit = function handleEdit() {
    setCurrentEditingRow(_extends({}, row));
    setAnchorEl(null);
  };

  return React.createElement(TableCell, {
    sx: commonTableBodyButtonCellStyles(tableInstance.state.densePadding)
  }, renderRowActions ? React.createElement(React.Fragment, null, renderRowActions(row, tableInstance)) : row.id === ((_tableInstance$state$ = tableInstance.state.currentEditingRow) == null ? void 0 : _tableInstance$state$.id) ? React.createElement(MRT_EditActionButtons, {
    row: row
  }) : !renderRowActionMenuItems && enableRowEditing ? React.createElement(Tooltip, {
    placement: "right",
    arrow: true,
    title: localization.edit
  }, React.createElement(IconButton, {
    sx: commonIconButtonStyles,
    onClick: handleEdit
  }, React.createElement(EditIcon, null))) : renderRowActionMenuItems ? React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.rowActions
  }, React.createElement(IconButton, {
    "aria-label": localization.rowActions,
    onClick: handleOpenRowActionMenu,
    size: "small",
    sx: commonIconButtonStyles
  }, React.createElement(MoreHorizIcon, null))), React.createElement(MRT_RowActionMenu, {
    anchorEl: anchorEl,
    handleEdit: handleEdit,
    row: row,
    setAnchorEl: setAnchorEl
  })) : null);
};

var MRT_TableBodyRow = function MRT_TableBodyRow(_ref) {
  var row = _ref.row;

  var _useMRT = useMRT(),
      anyRowsCanExpand = _useMRT.anyRowsCanExpand,
      enableRowActions = _useMRT.enableRowActions,
      enableRowEditing = _useMRT.enableRowEditing,
      enableRowNumbers = _useMRT.enableRowNumbers,
      enableSelection = _useMRT.enableSelection,
      muiTableBodyRowProps = _useMRT.muiTableBodyRowProps,
      onRowClick = _useMRT.onRowClick,
      positionActionsColumn = _useMRT.positionActionsColumn,
      renderDetailPanel = _useMRT.renderDetailPanel,
      tableInstance = _useMRT.tableInstance,
      densePadding = _useMRT.tableInstance.state.densePadding;

  var mTableBodyRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps(row) : muiTableBodyRowProps;

  var tableRowProps = _extends({}, mTableBodyRowProps, row.getRowProps(), {
    style: _extends({}, row.getRowProps().style, mTableBodyRowProps == null ? void 0 : mTableBodyRowProps.style)
  });

  return React.createElement(React.Fragment, null, React.createElement(TableRow, Object.assign({
    hover: true,
    onClick: function onClick(event) {
      return onRowClick == null ? void 0 : onRowClick(event, row);
    },
    selected: row.isSelected
  }, tableRowProps), enableRowNumbers && React.createElement(TableCell, {
    sx: _extends({}, commonTableBodyCellStyles(densePadding))
  }, row.index + 1), (enableRowActions || enableRowEditing) && positionActionsColumn === 'first' && React.createElement(MRT_ToggleRowActionMenuButton, {
    row: row
  }), (anyRowsCanExpand || renderDetailPanel) && React.createElement(MRT_ExpandButton, {
    row: row
  }), enableSelection && React.createElement(TableCell, {
    sx: _extends({}, commonTableBodyButtonCellStyles(tableInstance.state.densePadding), {
      maxWidth: '3rem',
      width: '3rem'
    })
  }, React.createElement(MRT_SelectCheckbox, {
    row: row
  })), row.cells.map(function (cell) {
    return React.createElement(MRT_TableBodyCell, {
      key: cell.getCellProps().key,
      cell: cell
    });
  }), (enableRowActions || enableRowEditing) && positionActionsColumn === 'last' && React.createElement(MRT_ToggleRowActionMenuButton, {
    row: row
  })), renderDetailPanel && !row.isGrouped && React.createElement(MRT_TableDetailPanel, {
    row: row
  }));
};

var MRT_TableBody = function MRT_TableBody() {
  var _useMRT = useMRT(),
      tableInstance = _useMRT.tableInstance,
      muiTableBodyProps = _useMRT.muiTableBodyProps,
      manualPagination = _useMRT.manualPagination;

  var rows = manualPagination ? tableInstance.rows : tableInstance.page;
  var mTableBodyProps = muiTableBodyProps instanceof Function ? muiTableBodyProps(tableInstance) : muiTableBodyProps;

  var tableBodyProps = _extends({}, mTableBodyProps, tableInstance.getTableBodyProps(), {
    style: _extends({}, tableInstance.getTableBodyProps().style, mTableBodyProps == null ? void 0 : mTableBodyProps.style)
  });

  return React.createElement(TableBody, Object.assign({}, tableBodyProps, {
    sx: _extends({}, tableBodyProps == null ? void 0 : tableBodyProps.sx)
  }), rows.map(function (row) {
    tableInstance.prepareRow(row);
    return React.createElement(MRT_TableBodyRow, {
      key: row.getRowProps().key,
      row: row
    });
  }));
};

var MRT_TableFooterCell = function MRT_TableFooterCell(_ref) {
  var _column$columns;

  var column = _ref.column;

  var _useMRT = useMRT(),
      muiTableFooterCellProps = _useMRT.muiTableFooterCellProps,
      enableColumnResizing = _useMRT.enableColumnResizing,
      densePadding = _useMRT.tableInstance.state.densePadding;

  var isParentHeader = !!(column != null && (_column$columns = column.columns) != null && _column$columns.length);
  var mTableFooterCellProps = muiTableFooterCellProps instanceof Function ? muiTableFooterCellProps(column) : muiTableFooterCellProps;
  var mcTableFooterCellProps = column.muiTableFooterCellProps instanceof Function ? column.muiTableFooterCellProps(column) : column.muiTableFooterCellProps;

  var tableCellProps = _extends({}, mTableFooterCellProps, mcTableFooterCellProps, column.getFooterProps(), {
    style: _extends({}, column.getFooterProps().style, mTableFooterCellProps == null ? void 0 : mTableFooterCellProps.style, mcTableFooterCellProps == null ? void 0 : mcTableFooterCellProps.style)
  });

  return React.createElement(TableCell, Object.assign({
    align: isParentHeader ? 'center' : 'left',
    variant: "head"
  }, tableCellProps, {
    sx: _extends({
      fontWeight: 'bold',
      verticalAlign: 'text-top',
      p: densePadding ? '0.5rem' : '1rem',
      transition: "all " + (enableColumnResizing ? '10ms' : '0.2s') + " ease-in-out"
    }, tableCellProps == null ? void 0 : tableCellProps.sx)
  }), column.render('Footer'));
};

var MRT_TableFooterRow = function MRT_TableFooterRow(_ref) {
  var footerGroup = _ref.footerGroup;

  var _useMRT = useMRT(),
      anyRowsCanExpand = _useMRT.anyRowsCanExpand,
      columns = _useMRT.columns,
      enableRowActions = _useMRT.enableRowActions,
      enableRowEditing = _useMRT.enableRowEditing,
      enableRowNumbers = _useMRT.enableRowNumbers,
      enableSelection = _useMRT.enableSelection,
      muiTableFooterRowProps = _useMRT.muiTableFooterRowProps,
      positionActionsColumn = _useMRT.positionActionsColumn,
      renderDetailPanel = _useMRT.renderDetailPanel,
      tableInstance = _useMRT.tableInstance; //if no content in row, skip row


  if (!(columns != null && columns.some(function (c) {
    return c.Footer;
  }))) return null;
  var mTableFooterRowProps = muiTableFooterRowProps instanceof Function ? muiTableFooterRowProps(footerGroup) : muiTableFooterRowProps;

  var tableRowProps = _extends({}, mTableFooterRowProps, footerGroup.getFooterGroupProps(), {
    style: _extends({}, footerGroup.getFooterGroupProps().style, mTableFooterRowProps == null ? void 0 : mTableFooterRowProps.style)
  });

  return React.createElement(TableRow, Object.assign({}, tableRowProps), enableRowNumbers && React.createElement(MRT_TableSpacerCell, null), (enableRowActions || enableRowEditing) && positionActionsColumn === 'first' && React.createElement(MRT_TableSpacerCell, null), (anyRowsCanExpand || renderDetailPanel) && React.createElement(MRT_TableSpacerCell, {
    width: (renderDetailPanel ? 2 : tableInstance.expandedDepth + 0.5) + "rem"
  }), enableSelection && React.createElement(MRT_TableSpacerCell, {
    width: "1rem"
  }), footerGroup.headers.map(function (column) {
    return React.createElement(MRT_TableFooterCell, {
      key: column.getFooterProps().key,
      column: column
    });
  }), (enableRowActions || enableRowEditing) && positionActionsColumn === 'last' && React.createElement(MRT_TableSpacerCell, null));
};

var MRT_TableFooter = function MRT_TableFooter() {
  var _useMRT = useMRT(),
      muiTableFooterProps = _useMRT.muiTableFooterProps,
      tableInstance = _useMRT.tableInstance;

  var tableFooterProps = muiTableFooterProps instanceof Function ? muiTableFooterProps(tableInstance) : muiTableFooterProps;
  return React.createElement(TableFooter, Object.assign({}, tableFooterProps), tableInstance.footerGroups.map(function (footerGroup) {
    return React.createElement(MRT_TableFooterRow, {
      key: footerGroup.getFooterGroupProps().key,
      footerGroup: footerGroup
    });
  }));
};

var MRT_Table = function MRT_Table() {
  var _useMRT = useMRT(),
      tableInstance = _useMRT.tableInstance,
      muiTableProps = _useMRT.muiTableProps,
      hideTableHead = _useMRT.hideTableHead,
      hideTableFooter = _useMRT.hideTableFooter;

  var mTableProps = muiTableProps instanceof Function ? muiTableProps(tableInstance) : muiTableProps;

  var tableProps = _extends({}, mTableProps, tableInstance.getTableProps(), {
    style: _extends({}, tableInstance.getTableProps().style, mTableProps == null ? void 0 : mTableProps.style)
  });

  return React.createElement(Table, Object.assign({}, tableProps), !hideTableHead && React.createElement(MRT_TableHead, null), React.createElement(MRT_TableBody, null), !hideTableFooter && React.createElement(MRT_TableFooter, null));
};

var MRT_SearchTextField = function MRT_SearchTextField() {
  var _useMRT = useMRT(),
      _useMRT$icons = _useMRT.icons,
      SearchIcon = _useMRT$icons.SearchIcon,
      CloseIcon = _useMRT$icons.CloseIcon,
      idPrefix = _useMRT.idPrefix,
      localization = _useMRT.localization,
      muiSearchTextFieldProps = _useMRT.muiSearchTextFieldProps,
      onGlobalFilterChange = _useMRT.onGlobalFilterChange,
      tableInstance = _useMRT.tableInstance;

  var _useState = useState(''),
      searchValue = _useState[0],
      setSearchValue = _useState[1];

  var handleChange = useAsyncDebounce(function (event) {
    var _event$target$value;

    tableInstance.setGlobalFilter((_event$target$value = event.target.value) != null ? _event$target$value : undefined);
    onGlobalFilterChange == null ? void 0 : onGlobalFilterChange(event);
  }, 200);

  var handleClear = function handleClear() {
    setSearchValue('');
    tableInstance.setGlobalFilter(undefined);
  };

  return React.createElement(Collapse, {
    "in": tableInstance.state.showSearch,
    orientation: "horizontal"
  }, React.createElement(TextField, Object.assign({
    id: "mrt-" + idPrefix + "-search-text-field",
    placeholder: localization.search,
    onChange: function onChange(event) {
      setSearchValue(event.target.value);
      handleChange(event);
    },
    value: searchValue != null ? searchValue : '',
    variant: "standard",
    InputProps: {
      startAdornment: React.createElement(InputAdornment, {
        position: "start"
      }, React.createElement(SearchIcon, {
        fontSize: "small"
      })),
      endAdornment: React.createElement(InputAdornment, {
        position: "end"
      }, React.createElement(IconButton, {
        "aria-label": localization.clearSearch,
        disabled: (searchValue == null ? void 0 : searchValue.length) === 0,
        onClick: handleClear,
        size: "small",
        title: localization.clearSearch
      }, React.createElement(CloseIcon, {
        fontSize: "small"
      })))
    }
  }, muiSearchTextFieldProps, {
    sx: _extends({
      justifySelf: 'end'
    }, muiSearchTextFieldProps == null ? void 0 : muiSearchTextFieldProps.sx)
  })));
};

var MRT_FullScreenToggleButton = function MRT_FullScreenToggleButton(_ref) {
  var rest = _extends({}, _ref);

  var _useMRT = useMRT(),
      _useMRT$icons = _useMRT.icons,
      FullscreenExitIcon = _useMRT$icons.FullscreenExitIcon,
      FullscreenIcon = _useMRT$icons.FullscreenIcon,
      localization = _useMRT.localization,
      setFullScreen = _useMRT.setFullScreen,
      fullScreen = _useMRT.tableInstance.state.fullScreen;

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.toggleFullScreen
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: function onClick() {
      return setFullScreen(!fullScreen);
    },
    size: "small"
  }, rest), fullScreen ? React.createElement(FullscreenExitIcon, null) : React.createElement(FullscreenIcon, null)));
};

var MRT_ShowHideColumnsButton = function MRT_ShowHideColumnsButton(_ref) {
  var rest = _extends({}, _ref);

  var _useMRT = useMRT(),
      ViewColumnIcon = _useMRT.icons.ViewColumnIcon,
      localization = _useMRT.localization;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    setAnchorEl(event.currentTarget);
  };

  return React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    title: localization.showHideColumns
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.showHideColumns,
    onClick: handleClick,
    size: "small"
  }, rest), React.createElement(ViewColumnIcon, null))), React.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: anchorEl,
    setAnchorEl: setAnchorEl
  }));
};

var MRT_ToggleDensePaddingButton = function MRT_ToggleDensePaddingButton(_ref) {
  var rest = _extends({}, _ref);

  var _useMRT = useMRT(),
      setDensePadding = _useMRT.setDensePadding,
      localization = _useMRT.localization,
      _useMRT$icons = _useMRT.icons,
      DensityMediumIcon = _useMRT$icons.DensityMediumIcon,
      DensitySmallIcon = _useMRT$icons.DensitySmallIcon,
      densePadding = _useMRT.tableInstance.state.densePadding;

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.toggleDensePadding
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.toggleDensePadding,
    onClick: function onClick() {
      return setDensePadding(!densePadding);
    },
    size: "small"
  }, rest), densePadding ? React.createElement(DensitySmallIcon, null) : React.createElement(DensityMediumIcon, null)));
};

var MRT_ToggleFiltersButton = function MRT_ToggleFiltersButton(_ref) {
  var rest = _extends({}, _ref);

  var _useMRT = useMRT(),
      _useMRT$icons = _useMRT.icons,
      FilterListIcon = _useMRT$icons.FilterListIcon,
      FilterListOffIcon = _useMRT$icons.FilterListOffIcon,
      localization = _useMRT.localization,
      setShowFilters = _useMRT.setShowFilters,
      showFilters = _useMRT.tableInstance.state.showFilters;

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.showHideFilters
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: function onClick() {
      return setShowFilters(!showFilters);
    },
    size: "small"
  }, rest), showFilters ? React.createElement(FilterListOffIcon, null) : React.createElement(FilterListIcon, null)));
};

var MRT_ToggleSearchButton = function MRT_ToggleSearchButton(_ref) {
  var rest = _extends({}, _ref);

  var _useMRT = useMRT(),
      _useMRT$icons = _useMRT.icons,
      SearchIcon = _useMRT$icons.SearchIcon,
      SearchOffIcon = _useMRT$icons.SearchOffIcon,
      idPrefix = _useMRT.idPrefix,
      localization = _useMRT.localization,
      muiSearchTextFieldProps = _useMRT.muiSearchTextFieldProps,
      setShowSearch = _useMRT.setShowSearch,
      showSearch = _useMRT.tableInstance.state.showSearch;

  var handleToggleSearch = function handleToggleSearch() {
    setShowSearch(!showSearch);
    setTimeout(function () {
      var _document$getElementB, _muiSearchTextFieldPr;

      return (_document$getElementB = document.getElementById((_muiSearchTextFieldPr = muiSearchTextFieldProps == null ? void 0 : muiSearchTextFieldProps.id) != null ? _muiSearchTextFieldPr : "mrt-" + idPrefix + "-search-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
  };

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.showHideSearch
  }, React.createElement(IconButton, Object.assign({
    size: "small",
    onClick: handleToggleSearch
  }, rest), showSearch ? React.createElement(SearchOffIcon, null) : React.createElement(SearchIcon, null)));
};

var MRT_ToolbarInternalButtons = function MRT_ToolbarInternalButtons() {
  var _useMRT = useMRT(),
      disableFilters = _useMRT.disableFilters,
      disableColumnHiding = _useMRT.disableColumnHiding,
      disableDensePaddingToggle = _useMRT.disableDensePaddingToggle,
      disableGlobalFilter = _useMRT.disableGlobalFilter,
      disableFullScreenToggle = _useMRT.disableFullScreenToggle,
      renderToolbarInternalActions = _useMRT.renderToolbarInternalActions,
      tableInstance = _useMRT.tableInstance;

  if (renderToolbarInternalActions) {
    return React.createElement(React.Fragment, null, renderToolbarInternalActions(tableInstance, {
      MRT_ToggleSearchButton: MRT_ToggleSearchButton,
      MRT_ToggleFiltersButton: MRT_ToggleFiltersButton,
      MRT_ShowHideColumnsButton: MRT_ShowHideColumnsButton,
      MRT_ToggleDensePaddingButton: MRT_ToggleDensePaddingButton,
      MRT_FullScreenToggleButton: MRT_FullScreenToggleButton
    }));
  }

  return React.createElement(Box, {
    sx: {
      display: 'flex',
      gap: '0.5rem',
      alignItems: 'center',
      p: '0 0.5rem'
    }
  }, !disableGlobalFilter && React.createElement(MRT_ToggleSearchButton, null), !disableFilters && React.createElement(MRT_ToggleFiltersButton, null), !disableColumnHiding && React.createElement(MRT_ShowHideColumnsButton, null), !disableDensePaddingToggle && React.createElement(MRT_ToggleDensePaddingButton, null), !disableFullScreenToggle && React.createElement(MRT_FullScreenToggleButton, null));
};

var MRT_TablePagination = function MRT_TablePagination() {
  var _useMRT = useMRT(),
      tableInstance = _useMRT.tableInstance,
      muiTablePaginationProps = _useMRT.muiTablePaginationProps;

  var tablePaginationProps = muiTablePaginationProps instanceof Function ? muiTablePaginationProps(tableInstance) : muiTablePaginationProps;

  var handleChangeRowsPerPage = function handleChangeRowsPerPage(event) {
    tableInstance.setPageSize(+event.target.value);
    tableInstance.gotoPage(0);
  };

  return React.createElement(TablePagination, Object.assign({
    component: 'div',
    count: tableInstance.rows.length,
    onPageChange: function onPageChange(_, newPage) {
      return tableInstance.gotoPage(newPage);
    },
    onRowsPerPageChange: handleChangeRowsPerPage,
    page: tableInstance.state.pageIndex,
    rowsPerPage: tableInstance.state.pageSize,
    SelectProps: {
      style: {
        margin: '0 1rem 0 1ch'
      }
    },
    showFirstButton: tableInstance.rows.length / tableInstance.state.pageSize > 2,
    showLastButton: tableInstance.rows.length / tableInstance.state.pageSize > 2
  }, tablePaginationProps, {
    sx: _extends({
      m: '0 0.5rem',
      position: 'relative',
      zIndex: 2
    }, tablePaginationProps == null ? void 0 : tablePaginationProps.sx)
  }));
};

var MRT_ToolbarAlertBanner = function MRT_ToolbarAlertBanner() {
  var _localization$selecte, _localization$selecte2;

  var _useMRT = useMRT(),
      muiTableToolbarAlertBannerProps = _useMRT.muiTableToolbarAlertBannerProps,
      tableInstance = _useMRT.tableInstance,
      positionToolbarAlertBanner = _useMRT.positionToolbarAlertBanner,
      positionToolbarActions = _useMRT.positionToolbarActions,
      localization = _useMRT.localization,
      renderToolbarCustomActions = _useMRT.renderToolbarCustomActions;

  var isMobile = useMediaQuery('(max-width:720px)');
  var alertProps = muiTableToolbarAlertBannerProps instanceof Function ? muiTableToolbarAlertBannerProps(tableInstance) : muiTableToolbarAlertBannerProps;
  var selectMessage = tableInstance.selectedFlatRows.length > 0 ? (_localization$selecte = localization.selectedCountOfRowCountRowsSelected) == null ? void 0 : (_localization$selecte2 = _localization$selecte.replace('{selectedCount}', tableInstance.selectedFlatRows.length.toString())) == null ? void 0 : _localization$selecte2.replace('{rowCount}', tableInstance.flatRows.length.toString()) : null;
  var groupedByMessage = tableInstance.state.groupBy.length > 0 ? React.createElement("span", null, localization.groupedBy, ' ', tableInstance.state.groupBy.map(function (columnId, index) {
    var _tableInstance$allCol;

    return React.createElement(Fragment, {
      key: index + "-" + columnId
    }, index > 0 ? localization.thenBy : '', React.createElement(Chip, {
      color: "secondary",
      label: (_tableInstance$allCol = tableInstance.allColumns.find(function (column) {
        return column.id === columnId;
      })) == null ? void 0 : _tableInstance$allCol.Header,
      onDelete: function onDelete() {
        return tableInstance.toggleGroupBy(columnId, false);
      }
    }));
  })) : null;
  var displayAbsolute = !(isMobile || positionToolbarAlertBanner === 'bottom' && positionToolbarActions === 'bottom' || positionToolbarAlertBanner === 'top' && !!renderToolbarCustomActions);
  return React.createElement(Collapse, {
    "in": !!selectMessage || !!groupedByMessage,
    timeout: displayAbsolute ? 0 : 200
  }, React.createElement(Alert, Object.assign({
    color: "info",
    icon: false,
    sx: _extends({
      borderRadius: 0,
      fontSize: '1rem',
      left: 0,
      p: 0,
      position: displayAbsolute ? 'absolute' : 'relative',
      right: 0,
      minHeight: '3.5rem',
      top: 0,
      width: '100%',
      zIndex: 2
    }, alertProps == null ? void 0 : alertProps.sx)
  }, alertProps), React.createElement(Box, {
    sx: {
      p: '0.5rem 1rem'
    }
  }, selectMessage, groupedByMessage)));
};

var MRT_LinearProgressBar = function MRT_LinearProgressBar() {
  var _useMRT = useMRT(),
      muiLinearProgressProps = _useMRT.muiLinearProgressProps,
      isFetching = _useMRT.isFetching,
      isLoading = _useMRT.isLoading,
      tableInstance = _useMRT.tableInstance;

  var linearProgressProps = muiLinearProgressProps instanceof Function ? muiLinearProgressProps(tableInstance) : muiLinearProgressProps;
  return React.createElement(Collapse, {
    "in": isFetching || isLoading,
    unmountOnExit: true
  }, React.createElement(LinearProgress, Object.assign({
    "aria-label": "Loading",
    "aria-busy": "true"
  }, linearProgressProps)));
};

var commonToolbarStyles = function commonToolbarStyles(theme, tableInstance) {
  return {
    backgroundColor: theme.palette.background["default"],
    backgroundImage: "linear-gradient(" + alpha(theme.palette.common.white, 0.05) + "," + alpha(theme.palette.common.white, 0.05) + ")",
    display: 'grid',
    opacity: tableInstance.state.fullScreen ? 0.95 : 1,
    p: '0 !important',
    width: '100%',
    zIndex: 1
  };
};
var MRT_ToolbarTop = function MRT_ToolbarTop() {
  var _renderToolbarCustomA;

  var _useMRT = useMRT(),
      disableGlobalFilter = _useMRT.disableGlobalFilter,
      hideToolbarInternalActions = _useMRT.hideToolbarInternalActions,
      manualPagination = _useMRT.manualPagination,
      muiTableToolbarTopProps = _useMRT.muiTableToolbarTopProps,
      positionPagination = _useMRT.positionPagination,
      positionToolbarActions = _useMRT.positionToolbarActions,
      positionToolbarAlertBanner = _useMRT.positionToolbarAlertBanner,
      renderToolbarCustomActions = _useMRT.renderToolbarCustomActions,
      tableInstance = _useMRT.tableInstance;

  var toolbarProps = muiTableToolbarTopProps instanceof Function ? muiTableToolbarTopProps(tableInstance) : muiTableToolbarTopProps;
  return React.createElement(Toolbar, Object.assign({
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({
        position: tableInstance.state.fullScreen ? 'sticky' : undefined,
        top: tableInstance.state.fullScreen ? '0' : undefined
      }, commonToolbarStyles(theme, tableInstance), toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), positionToolbarAlertBanner === 'top' && React.createElement(MRT_ToolbarAlertBanner, null), React.createElement(Box, {
    sx: {
      p: '0.5rem',
      display: 'flex',
      justifyContent: 'space-between'
    }
  }, (_renderToolbarCustomA = renderToolbarCustomActions == null ? void 0 : renderToolbarCustomActions(tableInstance)) != null ? _renderToolbarCustomA : React.createElement("span", null), React.createElement(Box, {
    sx: {
      display: 'flex',
      gap: '0.5rem',
      position: 'relative',
      zIndex: 3
    }
  }, !disableGlobalFilter && React.createElement(MRT_SearchTextField, null), !hideToolbarInternalActions && positionToolbarActions === 'top' && React.createElement(MRT_ToolbarInternalButtons, null))), React.createElement("div", null, !manualPagination && ['top', 'both'].includes(positionPagination != null ? positionPagination : '') && React.createElement(MRT_TablePagination, null)), React.createElement(MRT_LinearProgressBar, null));
};

var MRT_ToolbarBottom = function MRT_ToolbarBottom() {
  var _useMRT = useMRT(),
      hideToolbarInternalActions = _useMRT.hideToolbarInternalActions,
      manualPagination = _useMRT.manualPagination,
      muiTableToolbarBottomProps = _useMRT.muiTableToolbarBottomProps,
      positionPagination = _useMRT.positionPagination,
      positionToolbarActions = _useMRT.positionToolbarActions,
      positionToolbarAlertBanner = _useMRT.positionToolbarAlertBanner,
      tableInstance = _useMRT.tableInstance;

  var toolbarProps = muiTableToolbarBottomProps instanceof Function ? muiTableToolbarBottomProps(tableInstance) : muiTableToolbarBottomProps;
  return React.createElement(Toolbar, Object.assign({
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({
        bottom: tableInstance.state.fullScreen ? '0' : undefined,
        position: tableInstance.state.fullScreen ? 'fixed' : undefined
      }, commonToolbarStyles(theme, tableInstance), toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), React.createElement(MRT_LinearProgressBar, null), React.createElement(Box, {
    sx: {
      display: 'flex',
      justifyContent: 'space-between',
      width: '100%'
    }
  }, !hideToolbarInternalActions && positionToolbarActions === 'bottom' ? React.createElement(MRT_ToolbarInternalButtons, null) : React.createElement("span", null), positionToolbarAlertBanner === 'bottom' && React.createElement(MRT_ToolbarAlertBanner, null), !manualPagination && ['bottom', 'both'].includes(positionPagination != null ? positionPagination : '') && React.createElement(MRT_TablePagination, null)));
};

var MRT_TableContainer = function MRT_TableContainer() {
  var _useMRT = useMRT(),
      hideToolbarBottom = _useMRT.hideToolbarBottom,
      hideToolbarTop = _useMRT.hideToolbarTop,
      muiTableContainerProps = _useMRT.muiTableContainerProps,
      tableInstance = _useMRT.tableInstance;

  var fullScreen = tableInstance.state.fullScreen;
  useEffect(function () {
    if (typeof window !== 'undefined') {
      if (fullScreen) {
        document.body.style.overflow = 'hidden';
      } else {
        document.body.style.overflow = 'auto';
      }
    }
  }, [fullScreen]);
  var tableContainerProps = muiTableContainerProps instanceof Function ? muiTableContainerProps(tableInstance) : muiTableContainerProps;
  return React.createElement(TableContainer, Object.assign({
    component: Paper
  }, tableContainerProps, {
    sx: _extends({
      bottom: fullScreen ? '0' : undefined,
      height: fullScreen ? '100%' : undefined,
      left: fullScreen ? '0' : undefined,
      m: fullScreen ? '0' : undefined,
      overflowY: !fullScreen ? 'hidden' : undefined,
      position: fullScreen ? 'fixed' : undefined,
      right: fullScreen ? '0' : undefined,
      top: fullScreen ? '0' : undefined,
      transition: 'all 0.2s ease-in-out',
      width: fullScreen ? '100vw' : undefined,
      zIndex: fullScreen ? 1200 : 1
    }, tableContainerProps == null ? void 0 : tableContainerProps.sx)
  }), !hideToolbarTop && React.createElement(MRT_ToolbarTop, null), React.createElement(Box, {
    sx: {
      maxWidth: '100%',
      overflowX: 'auto'
    }
  }, React.createElement(MRT_Table, null)), !hideToolbarBottom && React.createElement(MRT_ToolbarBottom, null));
};

var MRT_DefaultLocalization_EN = {
  actions: 'Actions',
  cancel: 'Cancel',
  changeFilterMode: 'Change filter mode',
  clearFilter: 'Clear filter',
  clearSearch: 'Clear search',
  clearSort: 'Clear sort',
  clickToCopy: 'Click to copy',
  columnActions: 'Column Actions',
  copiedToClipboard: 'Copied to clipboard',
  edit: 'Edit',
  expand: 'Expand',
  expandAll: 'Expand all',
  filterByColumn: 'Filter by {column}',
  filterContains: 'Contains Exact',
  filterEmpty: 'Empty',
  filterEndsWith: 'Ends With',
  filterEquals: 'Equals',
  filterFuzzy: 'Fuzzy Match',
  filterGreaterThan: 'Greater Than',
  filterLessThan: 'Less Than',
  filterMode: 'Filter Mode: {filterType}',
  filterNotEmpty: 'Not Empty',
  filterNotEquals: 'Not Equals',
  filterStartsWith: 'Starts With',
  filteringByColumn: 'Filtering by {column} - {filterType} "{filterValue}"',
  groupByColumn: 'Group by {column}',
  groupedBy: 'Grouped by ',
  hideAll: 'Hide all',
  hideColumn: 'Hide {column} column',
  rowActions: 'Row Actions',
  save: 'Save',
  search: 'Search',
  selectedCountOfRowCountRowsSelected: '{selectedCount} of {rowCount} row(s) selected',
  showAll: 'Show all',
  showAllColumns: 'Show all columns',
  showHideColumns: 'Show/Hide columns',
  showHideFilters: 'Show/Hide filters',
  showHideSearch: 'Show/Hide search',
  sortByColumnAsc: 'Sort by {column} ascending',
  sortByColumnDesc: 'Sort by {column} descending',
  thenBy: ', then by ',
  toggleDensePadding: 'Toggle dense padding',
  toggleFullScreen: 'Toggle full screen',
  toggleSelectAll: 'Toggle select all',
  toggleSelectRow: 'Toggle select row',
  ungroupByColumn: 'Ungroup by {column}'
};

var MRT_Default_Icons = {
  ArrowRightIcon: ArrowRightIcon,
  CancelIcon: CancelIcon,
  CheckBoxIcon: CheckBoxIcon,
  ClearAllIcon: ClearAllIcon,
  CloseIcon: CloseIcon,
  ContentCopyIcon: ContentCopyIcon,
  DensityMediumIcon: DensityMediumIcon,
  DensitySmallIcon: DensitySmallIcon,
  DoubleArrowDownIcon: DoubleArrowDownIcon,
  DynamicFeedIcon: DynamicFeedIcon,
  EditIcon: EditIcon,
  ExpandLessIcon: ExpandLessIcon,
  ExpandMoreIcon: ExpandMoreIcon,
  FilterAltIcon: FilterAltIcon,
  FilterAltOff: FilterAltOff,
  FilterListIcon: FilterListIcon,
  FilterListOffIcon: FilterListOffIcon,
  FullscreenExitIcon: FullscreenExitIcon,
  FullscreenIcon: FullscreenIcon,
  MoreHorizIcon: MoreHorizIcon,
  MoreVertIcon: MoreVertIcon,
  SaveIcon: SaveIcon,
  SearchIcon: SearchIcon,
  SearchOffIcon: SearchOffIcon,
  SortIcon: SortIcon,
  ViewColumnIcon: ViewColumnIcon,
  VisibilityOffIcon: VisibilityOffIcon
};

var _excluded = ["defaultColumn", "filterTypes", "globalFilter", "icons", "localization", "positionActionsColumn", "positionPagination", "positionToolbarActions", "positionToolbarAlertBanner"];
var MaterialReactTable = (function (_ref) {
  var _ref$defaultColumn = _ref.defaultColumn,
      defaultColumn = _ref$defaultColumn === void 0 ? {
    minWidth: 50,
    maxWidth: 1000
  } : _ref$defaultColumn,
      filterTypes = _ref.filterTypes,
      _ref$globalFilter = _ref.globalFilter,
      globalFilter = _ref$globalFilter === void 0 ? 'fuzzy' : _ref$globalFilter,
      icons = _ref.icons,
      localization = _ref.localization,
      _ref$positionActionsC = _ref.positionActionsColumn,
      positionActionsColumn = _ref$positionActionsC === void 0 ? 'first' : _ref$positionActionsC,
      _ref$positionPaginati = _ref.positionPagination,
      positionPagination = _ref$positionPaginati === void 0 ? 'bottom' : _ref$positionPaginati,
      _ref$positionToolbarA = _ref.positionToolbarActions,
      positionToolbarActions = _ref$positionToolbarA === void 0 ? 'top' : _ref$positionToolbarA,
      _ref$positionToolbarA2 = _ref.positionToolbarAlertBanner,
      positionToolbarAlertBanner = _ref$positionToolbarA2 === void 0 ? 'top' : _ref$positionToolbarA2,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  return React.createElement(MaterialReactTableProvider //@ts-ignore
  , Object.assign({
    //@ts-ignore
    defaultColumn: defaultColumn,
    //@ts-ignore
    filterTypes: _extends({}, defaultFilterFNs, filterTypes),
    //@ts-ignore
    globalFilter: globalFilter,
    icons: _extends({}, MRT_Default_Icons, icons),
    localization: _extends({}, MRT_DefaultLocalization_EN, localization),
    positionActionsColumn: positionActionsColumn,
    positionPagination: positionPagination,
    positionToolbarActions: positionToolbarActions,
    positionToolbarAlertBanner: positionToolbarAlertBanner
  }, rest), React.createElement(MRT_TableContainer, null));
});

export default MaterialReactTable;
//# sourceMappingURL=material-react-table.esm.js.map
